<?php
session_start();
include '../db/db.php';

// Validate and sanitize input
$date1 = mysqli_real_escape_string($con, $_GET['date1']);
$date2 = mysqli_real_escape_string($con, $_GET['date2']);
$branch = mysqli_real_escape_string($con, $_GET['branch']);
$date3 = date('d-m-Y', strtotime($date1));
$date4 = date('d-m-Y', strtotime($date2));

// Determine date condition
if ($date1 !== $date2) {
    $date_condition = "gt.date BETWEEN '$date1' AND '$date2'";
    $note = "FOR THE PERIOD FROM {$date3} TO {$date4}";
} else {
    $date_condition = "gt.date = '$date1'";
    $note = "FOR THE DATE: {$date3}";
}

// Define base query
$query = "SELECT 
            gt.id, 
            gt.date, 
            gt.notes, 
            gt.amount, 
            td.bank, 
            cm.account_name AS transaction_account_name,
            cm2.account_name AS bank_account_name
        FROM gl_transaction gt
        INNER JOIN payment_transactions_details td ON gt.transid = td.id
        INNER JOIN chart_master cm ON gt.account = cm.account_code
        LEFT JOIN chart_master cm2 ON td.bank = cm2.account_code
        WHERE $date_condition 
        AND gt.fsli IN(18,19,20,21,22,28)
        AND gt.maingroup = 'Expense'";

// Add branch condition if not 'All'
if ($branch !== 'All') {
    $query .= " AND gt.branchno = '$branch'";
}

// Execute query
$result = mysqli_query($con, $query);

// Check for query execution errors
if (!$result) {
    die('Query Error: ' . mysqli_error($con));
}
?>
<!DOCTYPE html>
<html>
<head>
    <style>
        table {
            border-collapse: collapse;
            border: 1px solid black;
            width: 100%;
        }
        th, td {
            border: 1px solid black;
            padding: 8px;
            color: black;
        }
    </style>
</head>
<body>
<div class="col-md-9">
    <!-- START TIMELINE -->
    <div class="row">
        <div class="col-md-12">
            <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=accounting" style="color: rgb(7, 133, 164)"></a>Accounting Menu</li>
                <li class="active">Expenses Report</li>
            </ul>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>EXPENSES REPORT</b></h3>
                    <div class="pull-right">
                        <button class="btn btn-default" onclick="history.back()">
                            <span class="fa fa-arrow-left"></span> Go Back
                        </button>
                        <button class="btn btn-default" onclick="printTable()">
                            <span class="fa fa-print"></span> Print Report
                        </button>
                        <button class="btn btn-default" onclick="exportToExcel()">
                            <span class="fa fa-file-excel-o"></span> Export To Excel
                        </button>
                    </div>
                </div>
                <div class="panel-body" style="background: #fff">
                    <div id="printingArea">
                        <table id="myTable">
                            <tr>
                                <th colspan="6" style="text-align:center"><?php echo $_SESSION['Company']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="6" style="text-align:center">BRANCH: <?php echo htmlspecialchars($branch); ?></th>
                            </tr>
                            <tr>
                                <th colspan="6" style="text-align:center"><?php echo $note; ?></th>
                            </tr>
                            <tr style="font-weight: bold">
                                <td>#</td>
                                <td>Date</td>
                                <td>Description</td>
                                <td>Account</td>
                                <td>Paid From</td>
                                <td>Amount</td>
                            </tr>
                            <?php
                            $a = 1;
                            $sum1 = 0;
                            while ($rows = mysqli_fetch_assoc($result)) {
                                $sum1 += $rows['amount'];
                                ?>
                                <tr>
                                    <td><?php echo $a++; ?></td>
                                    <td><?php echo $rows['date']; ?></td>
                                    <td><?php echo $rows['notes']; ?></td>
                                    <td><?php echo $rows['transaction_account_name']; ?></td>
                                    <td><?php echo $rows['bank_account_name']; ?></td>
                                    <td style="text-align:right"><?php echo number_format($rows['amount'], 2); ?></td>
                                </tr>
                                <?php
                            }
                            ?>
                            <tr>
                                <td colspan="5" style="text-align:left"><b>TOTAL</b></td>
                                <td style="text-align:right"><b><?php echo number_format($sum1, 2); ?></b></td>
                            </tr>
                        </table>
                    </div>
                </div>
                <div class="panel-footer">
                </div>
            </div>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>
<script>
function printTable() {
    var cells = document.querySelectorAll('td, th');
    cells.forEach(function(cell) {
        cell.style.border = '1px solid black';
    });

    var printWindow = window.open('', '_blank');
    printWindow.document.open();
    printWindow.document.write('<html><head><title>Print Table</title></head><body>');
    printWindow.document.write('<style>table { border-collapse: collapse; width: 100%; } th, td { border: 1px solid black; padding: 8px; }</style>');
    printWindow.document.write(document.getElementById('myTable').outerHTML);
    printWindow.document.close();
    printWindow.print();

    cells.forEach(function(cell) {
        cell.style.border = '';
    });
}

function exportToExcel() {
    var table = document.getElementById('printingArea');
    var wb = XLSX.utils.table_to_book(table);
    var wbout = XLSX.write(wb, { bookType: 'xlsx', type: 'binary' });
    var blob = new Blob([s2ab(wbout)], { type: 'application/octet-stream' });

    var link = document.createElement('a');
    link.href = window.URL.createObjectURL(blob);
    link.download = 'inventory_profit_margin_report.xlsx';
    link.click();
}

function s2ab(s) {
    var buf = new ArrayBuffer(s.length);
    var view = new Uint8Array(buf);
    for (var i = 0; i < s.length; i++) {
        view[i] = s.charCodeAt(i) & 0xFF;
    }
    return buf;
}
</script>
</body>
</html>
