<?php
$branch = $_GET['branch'] ?? 'All'; 

try {
    $query = "SELECT ai.*, fa.asset_type 
              FROM assetitems ai
              LEFT JOIN fixedasset fa ON ai.fixedassetid = fa.id  WHERE ai.status = 0";

    if ($branch !== 'All') {
        $query .= " WHERE ai.branch = :branch";
    }

   
    $stmt = $pdo->prepare($query);
    if ($branch !== 'All') {
        $stmt->bindParam(':branch', $branch, PDO::PARAM_STR);
    }
    $stmt->execute();

    // Fetch the results
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

} catch (PDOException $e) {
    echo "Error: " . $e->getMessage();
    exit;
}
?>

<style>
    /* CSS to style the table */
    table {
        border-collapse: collapse;
        border: 1px solid black; /* Set border color and thickness */
        width: 100%; /* Set table width to 100% of its container */
    }

    th, td {
        border: 1px solid black; /* Set border for table cells */
        padding: 8px; /* Add padding for better readability */
        text-align: center; /* Center-align text within cells */
        height: 20px;
        color: black;
    }

    @media print {
        /* Additional styles to maintain table formatting for printing */
        table, th, td {
            border: 1px solid black !important; /* Ensure borders remain intact when printing */
        }
        tr { 
            page-break-inside: avoid; 
            page-break-after: auto; 
        }
        thead { display: table-header-group; }
        tfoot { display: table-footer-group; }
        td, th { 
            border: 1px solid #dddddd; 
            text-align: left; 
            padding: 8px; 
        }
    }
</style>



<div class="col-md-9">
    <!-- START TIMELINE -->
    <div class="row">
        <div class="col-md-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>Asset Location Report</b></h3>
                    <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=accounting" style="color: rgb(7, 133, 164)">Accounting</a></li>
                <li><a href="fixed_asset_tab.php" style="color: rgb(7, 133, 164)">Fixed Asset</a></li>
                <li class="active">Asset Location Report</li>
            </ul>
                    <div class="pull-right">
                        <button class="btn btn-default" onclick="printTableData()">
                            <span class="fa fa-print"></span> Export To PDF
                        </button>
                        <button class="btn btn-default" onclick="exportToExcel()">
                            <span class="fa fa-print"></span> Export To Excel
                        </button>
                    </div>
                </div>
                <div class="panel-body" style="background: #fff" id="printingArea">
                    <table id="myTable">
                        <thead>
                            <tr>
                                <th colspan="7" style="text-align:center"><?php echo $_SESSION['Company'];?></th>
                            </tr>
                            <tr style="text-align:center">
                                <th colspan="7" style="text-align:center">ASSET LOCATION REPORT</th>
                            </tr>
                            <tr>
                                <th colspan="7" style="text-align:center"><?php echo 'LOCATION ' . $branch;?></th>
                            </tr>
								<tr>
									<th>Asset Type</th>
									<th>Asset No.</th>
									<th>Asset Name</th>
									<th>Purchase cost</th>
									<th>Accum. deprec.</th>
									<th>Book Value</th>
									<th>Branch</th>
								</tr>
										</thead>
									<tbody>
            <?php if (!empty($results)): ?>
                <?php foreach ($results as $row): ?>
                    <tr>
                        <td style="text-align:left"><?php echo htmlspecialchars($row['asset_type']); ?></td>
                        <td style="text-align:left"><?php echo htmlspecialchars($row['item_number']); ?></td>
                        <td style="text-align:left"><?php echo htmlspecialchars($row['item_name']); ?></td>
                        <td style="text-align:right"><?php echo number_format($row['acquisition_cost'], 2); ?></td>
                        <td style="text-align:right"><?php echo number_format($row['accumulated_depreciation'], 2); ?></td>
                        <td style="text-align:right"><?php echo number_format($row['acquisition_cost'] - $row['accumulated_depreciation'], 2); ?></td>
                        <td style="text-align:right"><?php echo htmlspecialchars($row['branch']); ?></td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="7" style="text-align:center">No data available</td>
                </tr>
            <?php endif; ?>
        </tbody>
	     </table>
    </div>
                <div class="panel-footer">                                    
                </div>
            </div>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>
<script>
    function printTableData() {
        // Apply border style to table cells
        var cells = document.querySelectorAll('td, th');
        cells.forEach(function(cell) {
            cell.style.border = '1px solid black';
        });

        // Print only the table
        var printWindow = window.open('', '_blank');
        printWindow.document.open();
        printWindow.document.write('<html><head><title>Print Table</title></head><body>');
        printWindow.document.write('<style>table { border-collapse: collapse; width: 100%; } th, td { border: 1px solid black; padding: 8px; }</style>');
        printWindow.document.write(document.getElementById('myTable').outerHTML);
        printWindow.document.write('</body></html>');
        printWindow.document.close();
        printWindow.print();

        // Remove border style after printing
        cells.forEach(function(cell) {
            cell.style.border = '';
        });
    }
</script>

<script>
    function exportToExcel() {
        // Get the HTML table element
        var table = document.querySelector('table');

        // Convert the HTML table to a worksheet
        var wb = XLSX.utils.table_to_book(table);

        // Generate a binary string from the XLSX workbook
        var wbout = XLSX.write(wb, { bookType: 'xlsx', type: 'binary' });

        // Create a Blob object representing the data as an Excel file
        var blob = new Blob([s2ab(wbout)], { type: 'application/octet-stream' });

        // Create a temporary anchor element and trigger a download
        var link = document.createElement('a');
        link.href = window.URL.createObjectURL(blob);
        link.download = 'AssetItems_report.xlsx'; // Change 'filename' to your desired filename
        link.click();
    }

    // Utility function to convert a string to an ArrayBuffer
    function s2ab(s) {
        var buf = new ArrayBuffer(s.length);
        var view = new Uint8Array(buf);
        for (var i = 0; i < s.length; i++) {
            view[i] = s.charCodeAt(i) & 0xFF;
        }
        return buf;
    }
</script>
