<?php
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $date = filter_input(INPUT_POST, 'date', FILTER_SANITIZE_STRING);
    $reference = filter_input(INPUT_POST, 'reference', FILTER_SANITIZE_STRING);
    $note = filter_input(INPUT_POST, 'note', FILTER_SANITIZE_STRING);
    
    // Sanitize accounts, amounts, and nature arrays
    $accounts = filter_var_array($_POST['account'], FILTER_SANITIZE_STRING);
    $amounts = filter_var_array($_POST['amount'], FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
    $natures = filter_var_array($_POST['nature'], FILTER_SANITIZE_STRING);
    
    $userid = $_SESSION['id'];
    $cat = 'Journal';
    $branch = $_SESSION['Branch'];

    // Initialize totals for validation
    $totalDebits = 0;
    $totalCredits = 0;

    // Calculate the total debits and credits
    foreach ($amounts as $index => $amount) {
        $amount = floatval($amount); // Ensure amount is a number
        if ($natures[$index] === 'Debit') {
            $totalDebits += $amount;
        } elseif ($natures[$index] === 'Credit') {
            $totalCredits += $amount;
        }
    }

    // Check if debits and credits are equal
    if ($totalDebits !== $totalCredits) {
        echo "<script>
               alert('Journal is Not Balance');
            </script>";

    } else {
        // Debits and credits are balanced, proceed with database insertion
        try {
            // Start a transaction
            $pdo->beginTransaction();

            // Insert into the journal voucher table
            $sql = "INSERT INTO journal (Date, Note, Debit, Credit, User,Reference, Branch) VALUES (:Date, :Note, :Debit, :Credit, :User,:Reference, :Branch)";
            $stmt = $pdo->prepare($sql);
            $stmt->execute([
                ':Date' => $date,
                ':Note' => $note,
                ':Debit' => $totalDebits,
                ':Credit' => $totalCredits,
                ':User' => $userid,
                ':Reference' => $reference,
                ':Branch' => $branch
            ]);

            // Get the last inserted journal voucher ID
            $journalId = $pdo->lastInsertId();

            // Insert each line into the journal_lines table
            foreach ($accounts as $index => $account) {
                $amount = floatval($amounts[$index]); // Ensure amount is numeric
                $nature = $natures[$index];
                
                $fetchAccountQuery = "SELECT * FROM chart_master WHERE `account_code` = ?";
                $stmt_fetch = $pdo->prepare($fetchAccountQuery);
                $stmt_fetch->execute([$account]);
                $accountDetails = $stmt_fetch->fetch(PDO::FETCH_ASSOC);
    
                // Ensure you're fetching the correct columns from $accountDetails
                $fsli = $accountDetails['account_type'];
                $maingroup = $accountDetails['class'];
                
                // Prepare and execute INSERT statement for gl_transaction
                $insertTransQuery = "INSERT INTO gl_transaction (`account`, `fsli`, `maingroup`, `amount`, `nature`, `transid`, `user`, `notes`, `date`, `branchno`, `cat`)
                                    VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
                $stmt_trans_query = $pdo->prepare($insertTransQuery);
                $stmt_trans_query->execute([$account, $fsli, $maingroup, $amount, $nature, $journalId, $userid, $note, $date, $branch, $cat]);
            }

            // Commit the transaction
            $pdo->commit();

            echo "<script>
               alert('Journal Successfully Created');
               window.location='index.php?p=journal';
            </script>";

        } catch (Exception $e) {
            // Rollback in case of error
            $pdo->rollBack();
            echo "<p style='color:red;'>Error: " . $e->getMessage() . "</p>";
        }
    }
}
?>
<div class="col-md-9">
    <!-- START TIMELINE -->
    <div class="row">
        <div class="col-md-12">
            <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                    <li><a href="index.php?p=accounting" style="color: rgb(7, 133, 164)">Accounting Menu</a></li>
                    <li><a href="index.php?p=journal" style="color: rgb(7, 133, 164)">Journal List</a></li>
                    <li class="active">New Journal</li>
                    </ul>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>JOURNAL VOUCHER</b></h3>
                </div>
                <div class="panel-body">
                    <center><img src="../../../logo/load.gif" id="loading" style="display:none"></center>
                    <form class="form-horizontal" method="post" action="" enctype="multipart/form-data">
                    <!--<form class="form-horizontal" method="post" action="" enctype="multipart/form-data" id="myFormData" onsubmit="submitForm(event)">-->
        <h4 style="font-weight: bold;color: rgb(193, 190, 190);">New Journal</h4>            
        <table class="table" style="width: 80%;">
            <tbody>
                <tr>
                    <th style="width:40%" colspan=2>
                        <div class="form-group">
                            <label class="col-md-12 col-xs-12">Date *</label>
                                <div class="col-md-12 col-xs-12">            
                                <input type="text" class="form-control datepicker" name = "date" value="<?php echo date('Y-m-d');?>"/>            
                            </div>
                        </div> 
                    </th>
                    <th style="width:40%" colspan=2>
                        <div class="form-group">
                            <label class="col-md-12 col-xs-12">Reference</label>
                        <div class="col-md-12 col-xs-12">                       
                          <div class="input-group">
                             <span class="input-group-addon"><input type="checkbox" id="referenceCheckbox"></span>
                            <input type="text" class="form-control" id="referenceInput" placeholder="Optional" name="reference">
                      </div>                                            
                    </div>
                  </div>
                    </th>
                </tr>
            <tr>
                <th colspan="4" style="width:80%">Transaction Description</th>
              </tr>
            <tr>
                <td colspan="4" style="width:80%">
                    <div class="form-group">
                        <div class="col-md-12 col-xs-12">                       
                            <textarea class="form-control" name="note" required></textarea>
                    </div>
                  </div>
                </td>
            </tr>
            <tr>
                <th style="width:25%">Account</th>
                <th style="width:25%">Debit/Credit</th>
                <th style="width:25%">Amount</th>
                <th style="width:5%"></th>
            </tr>
              <tr>
                <td style="width:25%">
                    <div class="form-group">
                        <div class="col-md-12 col-xs-12">                       
                                    <select class="form-control select" name= "account[]" data-live-search="true">
                                                  <?php
                                                  $cl = mysqli_query($con,"SELECT * FROM chart_master ORDER BY account_name ASC");
                                                    while($class = mysqli_fetch_assoc($cl)){
                                                  ?>
                                                        <option value = "<?php echo $class['account_code'];?>"><?php echo $class['account_code'];?> - <?php echo $class['account_name'];?></option>
                                                     <?php
                                                       }
                                                      ?>
                                </select>
                    </div>
                   </div>
                </td>
                
                <!-- Debit/Credit selection in initial row -->
                <td style="width:25%">
                    <div class="form-group">
                        <div class="col-md-12 col-xs-12">                       
                            <select class="form-control select" name="nature[]" onchange="updateTotalAmount()">
                                <option value="Debit">Debit</option>
                                <option value="Credit">Credit</option>
                            </select>
                        </div>
                    </div>
                </td>

                
                <td style="width:25%">
                    <div class="form-group">
                        <div class="col-md-12 col-xs-12">                       
                                    <input type="text" oninput="updateTotalAmount()" name = "amount[]" class="form-control" style="width:100%"/>
                    </div>
                  </div>
                </td>
                <td style="width:5%">
                </td>    
                </tr>
                <tr>
                    <td>
                        <span><button type="button" class="btn btn-primary" onclick="addAccountLine()" style="background-color: green;color: white;">Add Line</button></span>
                    </td>
                    <td align="right">
                        <div class="form-group">
                            <label for="totalDebits" style="color:red;font-size:16px">Total Debits:</label>
                            <input type="text" id="totalDebits" class="form-control" style="color:red;width:150px" readonly value="0.00" />
                        </div>
                    </td>
                    <td align="right">
                        <div class="form-group">
                            <label for="totalCredits" style="color:red;font-size:16px">Total Credits:</label>
                            <input type="text" id="totalCredits" class="form-control" style="color:red;width:150px" readonly value="0.00" />
                        </div>
                    </td>

                </tr>
            </tbody>    
        </table>
                </div>
                <div class="panel-footer">
                    <button id = "submitInput" style="display:none" type="submit" name="submit" class="btn btn-info pull-right"><span class="fa fa-plus-circle"></span> Create </button>
                </div>
                </form>
            </div>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>
<script>
let voucherCounter = 1; // Initialize the voucher counter

// Function to add a new account line
function addAccountLine() {
    const tableBody = document.querySelector('.table tbody');

    const newRow = document.createElement('tr');
    newRow.innerHTML = `
        <td style="width:25%">
            <div class="form-group">
                <div class="col-md-12 col-xs-12">
                    <select class="form-control select" name="account[]" data-live-search="true">
                        <?php
                        $cl = mysqli_query($con,"SELECT * FROM chart_master ORDER BY account_name ASC");
                        while($class = mysqli_fetch_assoc($cl)){
                        ?>
                            <option value="<?php echo $class['account_code'];?>"><?php echo $class['account_code'];?> - <?php echo $class['account_name'];?></option>
                        <?php } ?>
                    </select>
                </div>
            </div>
        </td>
        <td style="width:25%">
            <div class="form-group">
                <div class="col-md-12 col-xs-12">
                    <select class="form-control select" name="nature[]" onchange="updateTotalAmount()">
                        <option value="Debit">Debit</option>
                        <option value="Credit">Credit</option>
                    </select>
                </div>
            </div>
        </td>
        <td style="width:25%">
            <div class="form-group">
                <div class="col-md-12 col-xs-12">
                    <input type="text" name="amount[]" class="form-control" oninput="updateTotalAmount()" />
                </div>
            </div>
        </td>
        <td style="width:5%; background-color:#ffffff">
            <button class="btn btn-danger" onclick="removeAccountLine(this)"><i class="fa fa-trash-o"></i></button>
        </td>
    `;


    // Initialize Bootstrap Selectpicker for the newly added row
    $(newRow.querySelectorAll('.select')).selectpicker();

    // Insert new row just above the last row (the one containing "Add Line" button)
    tableBody.insertBefore(newRow, tableBody.lastElementChild);

    // Update the sum of amounts
    updateTotalAmount();
}

// Function to remove an account line
function removeAccountLine(button) {
    const row = button.closest('tr');
    row.remove();

    // Update the sum of amounts after removing the line
    updateTotalAmount();
}

// Function to update the total amounts (debit and credit)
function updateTotalAmount() {
    const amounts = document.querySelectorAll('input[name="amount[]"]');
    const natures = document.querySelectorAll('select[name="nature[]"]');
    let totalDebits = 0;
    let totalCredits = 0;

    // Loop through amounts and natures to calculate totals
    amounts.forEach((input, index) => {
        const amount = parseFloat(input.value) || 0;
        const nature = natures[index].value;
        if (nature === "Debit") {
            totalDebits += amount;
        } else if (nature === "Credit") {
            totalCredits += amount;
        }
    });

    // Format totals to display with commas
    const formattedDebits = totalDebits.toLocaleString();
    const formattedCredits = totalCredits.toLocaleString();

    // Set the total values into the inputs
    document.getElementById('totalDebits').value = formattedDebits;
    document.getElementById('totalCredits').value = formattedCredits;

    // Check if debit and credit are equal
    const totalDebitsInput = document.getElementById('totalDebits');
    const totalCreditsInput = document.getElementById('totalCredits');
    const submitInput = document.getElementById('submitInput');
    
    if (totalDebits === totalCredits) {
        // If they are equal, set a green border
        totalDebitsInput.style.borderColor = "green";
        totalCreditsInput.style.borderColor = "green";
        submitInput.style.display = "block";
    } else {
        // If they are not equal, set a red border
        totalDebitsInput.style.borderColor = "red";
        totalCreditsInput.style.borderColor = "red";
        submitInput.style.display = "none";
    }
}
    
</script>
<script>
        function submitForm(event) {
            event.preventDefault();
            
            document.getElementById('loading').style.display = 'block';
            
            var formData = new FormData(document.getElementById("myFormData"));
            var xhr = new XMLHttpRequest();
            xhr.open("POST", "save_create_journal.php", true);
            xhr.onload = function () {
                
             document.getElementById('loading').style.display = 'none';
             
                if (xhr.status === 200) {

                    console.log(xhr.responseText);
                    console.log("Response Text Length:", xhr.responseText.length);
                    if (xhr.responseText.trim() === "2") {
                        Swal.fire({
                            position: "top",
                            icon: "success",
                            title: "Journal Submitted Successfully",
                            showConfirmButton: false,
                            timer: 1500
                        }).then(function() {
                            // After the Swal.fire() dialog is closed
                            location.reload(); // Reload the page
                        });
                    }else if(xhr.responseText.trim() === "1"){
                      Swal.fire({
                    position: "top",
                    icon: "info",
                    title: "Total Debits and Credits are not Equal",
                    showConfirmButton: false,
                    timer: 1500
                  });   
                    }else{
                       Swal.fire({
                    position: "top",
                    icon: "error",
                    title: "Something Wrong with database",
                    showConfirmButton: false,
                    timer: 1500
                  });   
                    }
                } else {
                    //alert('Request failed. Please try again later.');
                       Swal.fire({
                    position: "top",
                    icon: "error",
                    title: "Request failed. Please try again later",
                    showConfirmButton: false,
                    timer: 1500
                  });
                }
            };
            xhr.send(formData);
        }
</script>        
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@10"></script>
<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>