<?php
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get form data
    $date = filter_input(INPUT_POST, 'date', FILTER_SANITIZE_STRING);
    $reference = filter_input(INPUT_POST, 'reference', FILTER_SANITIZE_STRING);
    $note = filter_input(INPUT_POST, 'note', FILTER_SANITIZE_STRING);
    
    // Sanitize accounts, amounts, and nature arrays
    $accounts = filter_var_array($_POST['account'], FILTER_SANITIZE_STRING);
    $amounts = filter_var_array($_POST['amount'], FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
    $natures = filter_var_array($_POST['nature'], FILTER_SANITIZE_STRING);
    
    $userid = $_SESSION['id'];
    $cat = 'Journal';
    $branch = $_SESSION['Branch'];

    // Initialize totals for validation
    $totalDebits = 0;
    $totalCredits = 0;

    // Calculate the total debits and credits
    foreach ($amounts as $index => $amount) {
        $amount = floatval($amount); // Ensure amount is a number
        if ($natures[$index] === 'Debit') {
            $totalDebits += $amount;
        } elseif ($natures[$index] === 'Credit') {
            $totalCredits += $amount;
        }
    }

    // Check if debits and credits are equal
    if ($totalDebits !== $totalCredits) {
        echo "<script>
            alert('Debits and Credits are not equal. Please correct the amounts');
        </script>";
    } else {
        // Debits and credits are balanced, proceed with database insertion
        try {
            // Start a transaction
            $pdo->beginTransaction();

            // Insert into the journal voucher table
            $sql = "UPDATE journal 
                    SET Date = :Date, 
                        Note = :Note, 
                        Debit = :Debit, 
                        Credit = :Credit, 
                        User = :User, 
                        Reference = :Reference 
                    WHERE Id = :id";
            
            $stmt = $pdo->prepare($sql);
            $stmt->execute([
                ':Date' => $date,
                ':Note' => $note,
                ':Debit' => $totalDebits,
                ':Credit' => $totalCredits,
                ':User' => $userid,
                ':Reference' => $reference,
                ':id' => $id 
            ]);

            $sqlDel = "DELETE FROM gl_transaction WHERE transid = :id AND cat = 'Journal'";
            $stmt = $pdo->prepare($sqlDel);
            $stmt->execute([
                ':id' => $id
            ]);

            // Insert each line into the journal_lines table
            foreach ($accounts as $index => $account) {
                $amount = floatval($amounts[$index]); // Ensure amount is numeric
                $nature = $natures[$index];
                
                $fetchAccountQuery = "SELECT * FROM chart_master WHERE `account_code` = ?";
                $stmt_fetch = $pdo->prepare($fetchAccountQuery);
                $stmt_fetch->execute([$account]);
                $accountDetails = $stmt_fetch->fetch(PDO::FETCH_ASSOC);
    
                // Ensure you're fetching the correct columns from $accountDetails
                $fsli = $accountDetails['account_type'];
                $maingroup = $accountDetails['class'];
                
                // Prepare and execute INSERT statement for gl_transaction
                $insertTransQuery = "INSERT INTO gl_transaction (`account`, `fsli`, `maingroup`, `amount`, `nature`, `transid`, `user`, `notes`, `date`, `branchno`, `cat`)
                                    VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
                $stmt_trans_query = $pdo->prepare($insertTransQuery);
                $stmt_trans_query->execute([$account, $fsli, $maingroup, $amount, $nature, $id, $userid, $note, $date, $branch, $cat]);
            }

            // Commit the transaction
            $pdo->commit();

            echo "<p style='color:green;'>Journal Voucher Updated successfully!</p>";
            
            echo "<script>
            alert('Journal Voucher Updated successfully!');
            window.location.href = 'index.php?p=journal';
        </script>";

        } catch (Exception $e) {
            // Rollback in case of error
            $pdo->rollBack();
            echo "<p style='color:red;'>Error: " . $e->getMessage() . "</p>";
        }
    }
}
?>