<?php
// Include the database connection file
include '../db/connect.php';

try {
    // Check if country_id is provided via GET
    if (isset($_GET['country_id'])) {
        $country_id = $_GET['country_id'];

        // Prepare the SQL query to retrieve the currency and currency_name for the given country_id
        $stmt = $pdo->prepare("SELECT currency, currency_name FROM countries WHERE id = :country_id");
        $stmt->bindParam(':country_id', $country_id, PDO::PARAM_INT);
        
        // Execute the query
        $stmt->execute();
        
        // Fetch the result as an associative array
        $currency = $stmt->fetch(PDO::FETCH_ASSOC);
        
        // Set the content type to JSON
        header('Content-Type: application/json');
        
        if ($currency) {
            // Set HTTP response code to 200 (OK)
            http_response_code(200);
            echo json_encode($currency);
        } else {
            // Set HTTP response code to 404 (Not Found) if no data is found
            http_response_code(404);
            echo json_encode(['message' => 'No currency data found for the given country ID']);
        }
    } else {
        // Set HTTP response code to 400 (Bad Request) if country_id is not provided
        http_response_code(400);
        echo json_encode(['error' => 'country_id parameter is required']);
    }
    
} catch (PDOException $e) {
    // Set HTTP response code to 500 (Internal Server Error) in case of a database error
    http_response_code(500);
    echo json_encode(['error' => 'Database error: ' . $e->getMessage()]);
}
?>
