<?php
session_start();
include '../db/db.php';
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

$id = $_GET['id'];
$name = $_GET['name'];
$branch = $_SESSION['Branch'];
$user_id = $_SESSION['id'];

$item_movements = [];

// Opening Balance (adds to stock)
$sqlItemOpening = "SELECT io.date, 'Opening Balance' AS description, ist.quantity
                   FROM item_opening AS io
                   INNER JOIN item_stock_table AS ist ON io.id = ist.open_id
                   WHERE ist.itemid = :item_id AND io.branch = :branch";
$stmt = $pdo->prepare($sqlItemOpening);
$stmt->bindParam(':item_id', $id);
$stmt->bindParam(':branch', $branch);
$stmt->execute();
$item_movements = array_merge($item_movements, $stmt->fetchAll(PDO::FETCH_ASSOC));

// Purchases (adds to stock)
$sqlPurchases = "SELECT p.purchase_date AS date, 'Purchase' AS description, pi.quantity
                 FROM purchases AS p
                 INNER JOIN purchase_items AS pi ON p.purchase_id = pi.purchase_no
                 WHERE pi.product_id = :item_id AND p.branchno = :branch";
$stmt = $pdo->prepare($sqlPurchases);
$stmt->bindParam(':item_id', $id);
$stmt->bindParam(':branch', $branch);
$stmt->execute();
$item_movements = array_merge($item_movements, $stmt->fetchAll(PDO::FETCH_ASSOC));

// Purchase Invoice (adds to stock)
$sqlPurchaseInvoice = "SELECT pi.purchase_date AS date, 'Purchase Invoice' AS description, pii.quantity
                       FROM purchase_invoice AS pi
                       INNER JOIN purchase_invoice_items AS pii ON pi.purchase_id = pii.purchase_no
                       WHERE pii.product_id = :item_id AND pi.branchno = :branch";
$stmt = $pdo->prepare($sqlPurchaseInvoice);
$stmt->bindParam(':item_id', $id);
$stmt->bindParam(':branch', $branch);
$stmt->execute();
$item_movements = array_merge($item_movements, $stmt->fetchAll(PDO::FETCH_ASSOC));

// Sales Invoice (reduces stock)
$sqlInvoices = "SELECT i.invoice_date AS date, 'Sales Invoice' AS description, -ii.quantity AS quantity
                FROM invoices AS i
                INNER JOIN invoice_items AS ii ON i.invoice_id = ii.invoice_no
                WHERE ii.product_id = :item_id AND i.branchno = :branch";
$stmt = $pdo->prepare($sqlInvoices);
$stmt->bindParam(':item_id', $id);
$stmt->bindParam(':branch', $branch);
$stmt->execute();
$item_movements = array_merge($item_movements, $stmt->fetchAll(PDO::FETCH_ASSOC));

// Sales cash (reduces stock)
$sqlCashes = "SELECT i.invoice_date AS date, 'Cash Sales' AS description, -ii.quantity AS quantity
                FROM sales_cash AS i
                INNER JOIN sales_cash_items AS ii ON i.sales_cash_id = ii.cash_no
                WHERE ii.product_id = :item_id AND i.branchno = :branch";
$stmt = $pdo->prepare($sqlCashes);
$stmt->bindParam(':item_id', $id);
$stmt->bindParam(':branch', $branch);
$stmt->execute();
$item_movements = array_merge($item_movements, $stmt->fetchAll(PDO::FETCH_ASSOC));
// Write-Off (reduces stock)
$sqlWriteOff = "SELECT w.date, 'Write-Off' AS description, -wi.quantity AS quantity
                FROM writeoff AS w
                INNER JOIN writeoff_items AS wi ON w.id = wi.writeoff_id
                WHERE wi.itemid = :item_id AND w.branch = :branch";
$stmt = $pdo->prepare($sqlWriteOff);
$stmt->bindParam(':item_id', $id);
$stmt->bindParam(':branch', $branch);
$stmt->execute();
$item_movements = array_merge($item_movements, $stmt->fetchAll(PDO::FETCH_ASSOC));


// Sort results by date
usort($item_movements, function ($a, $b) {
    return strtotime($a['date']) - strtotime($b['date']);
});
?>

<style>
    table {
        border-collapse: collapse;
        border: 1px solid black;
        width: 100%;
    }

    th, td {
        border: 1px solid black;
        padding: 8px;
        text-align: center;
        height: 20px;
        color: black;
    }
</style>

<div class="col-md-9">
    <div class="row">
        <div class="col-md-12">
            <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=item_menu" style="color: rgb(7, 133, 164)">Items List</a></li>
                <li class="active">Item Movement</li>
            </ul>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>ITEM MOVEMENT</b></h3>
                    <div class="pull-right">
                        <button class="btn btn-default" onclick="history.back()"> <span class="fa fa-arrow-left"></span> Go Back</button>
                        <button class="btn btn-default" onclick="printContent()">
                            <span class="fa fa-print"></span> Print Report
                        </button>
                    </div>
                </div>
                <div class="panel-body" style="background: #fff">
                    <div id="printingArea">
                        <table id="myTable">
                            <tr>
                                <th colspan=4><?php echo $_SESSION['Company'];?></th>
                            </tr>
                            <tr>
                                <th colspan=4>BRANCH: <?php echo $_SESSION['Branch'];?></th>
                            </tr>
                            <tr>
                                <th colspan=4>ITEM NAME: <?php echo $name;?></th>
                            </tr>
                            <tr style="font-weight:bold">
                                <th>DATE</th>
                                <th>DESCRIPTION</th>
                                <th>QUANTITY</th>
                                <th>BALANCE</th>
                            </tr>
                            <tbody>
                            <?php
                            $balance = 0;
                            foreach ($item_movements as $movement) {
                                $balance += $movement['quantity']; // Update balance
                                $quantityColor = $movement['quantity'] < 0 ? 'red' : 'black'; // Red for reductions

                                echo "<tr>";
                                echo "<td>" . date('d-m-Y', strtotime($movement['date'])) . "</td>";
                                echo "<td>" . htmlspecialchars($movement['description']) . "</td>";
                                echo "<td style='color: $quantityColor;'>" . htmlspecialchars($movement['quantity']) . "</td>";
                                echo "<td>" . htmlspecialchars($balance) . "</td>";
                                echo "</tr>";
                            }
                            ?>
                            <tr style="font-weight:bold">
                                <td colspan="3" style="text-align:left;">TOTAL</td>
                                <td><?php echo $balance; ?></td>
                            </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    function printContent() {
        var content = document.getElementById('printingArea').innerHTML;
        var printWindow = window.open('', '_blank');
        printWindow.document.write('<html><head><title>Print</title>');
        printWindow.document.write('<style>table { border-collapse: collapse; border: 1px solid black; width: 100%; } th, td { border: 1px solid black; padding: 8px; text-align: center; height: 20px; color: black; }</style>');
        printWindow.document.write('</head><body>');
        printWindow.document.write(content);
        printWindow.document.write('</body></html>');
        printWindow.document.close();
        printWindow.print();
    }
</script>
