<?php
session_start();
include '../db/db.php';

if (isset($_POST['submit'])) {
    // Validate form data
    $date = filter_var($_POST['date'], FILTER_SANITIZE_STRING);
    $reference = filter_var($_POST['reference'], FILTER_SANITIZE_STRING);
    $from_branch = filter_var($_POST['from_branch'], FILTER_SANITIZE_STRING);
    $to_branch = filter_var($_POST['to_branch'], FILTER_SANITIZE_STRING);
    $note = filter_var($_POST['note'], FILTER_SANITIZE_STRING);
    $items = array_map('intval', $_POST['item']); // Ensure item IDs are integers
    $quantities = array_map('intval', $_POST['amount']); // Ensure quantities are integers

    if (empty($date) || empty($from_branch) || empty($to_branch) || empty($items) || empty($quantities)) {
        echo "<script>
            alert('All fields are required.');
            window.location.href='index.php?p=add_transfer';
        </script>";
        exit;
    }

    // Get user ID and branch from session
    $user_id = $_SESSION['id'];
    $branch = $_SESSION['Branch'];

    try {
        // Insert data into transfer_details
        $stmt = $pdo->prepare("INSERT INTO transfer_details (date, reference, `from`, `to`, notes, user, branch) VALUES (:date, :reference, :from_branch, :to_branch, :note, :user_id, :branch)");
        $stmt->execute([
            ':date' => $date,
            ':reference' => $reference,
            ':from_branch' => $from_branch,
            ':to_branch' => $to_branch,
            ':note' => $note,
            ':user_id' => $user_id,
            ':branch' => $branch
        ]);

        // Get the last inserted transfer_details ID
        $transfer_id = $pdo->lastInsertId();

        // Insert data into transfer_items
        for ($i = 0; $i < count($items); $i++) {
            $stmt = $pdo->prepare("INSERT INTO transfer_items (item_id, transfer_id, quantity) VALUES (:item_id, :transfer_id, :quantity)");
            $stmt->execute([
                ':item_id' => $items[$i],
                ':transfer_id' => $transfer_id,
                ':quantity' => $quantities[$i]
            ]);
        }

        // Redirect to a confirmation page or display a success message
        echo "<script>
            alert('Transfer has been successfully added.');
            window.location.href='index.php?p=transfer';
        </script>";
    } catch (PDOException $e) {
        echo "<script>
            alert('Error: " . htmlspecialchars($e->getMessage()) . "');
            window.location.href='index.php?p=transfer';
        </script>";
    }
}
?>

<div class="col-md-9">
    <!-- START TIMELINE -->
    <div class="row">
        <div class="col-md-12">
            <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=accounting" style="color: rgb(7, 133, 164)">Items Menu</a></li>
                <li><a href="index.php?p=transfer" style="color: rgb(7, 133, 164)">Transfer List</a></li>
                <li class="active">Add Transfer</li>
            </ul>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>ADD TRANSFER</b></h3>
                </div>
                <div class="panel-body">
                    <form class="form-horizontal" method="post" action="" enctype="multipart/form-data">           
                        <table class="table" style="width: 70%;">
                            <tbody>
                                <tr>
                                    <th style="width:35%">
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Date *</label>
                                            <div class="col-md-12 col-xs-12">            
                                                <input type="text" class="form-control datepicker" name="date" value="<?php echo date('Y-m-d');?>" />            
                                            </div>
                                        </div> 
                                    </th>
                                    <th style="width:35%">
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Reference</label>
                                            <div class="col-md-12 col-xs-12">                       
                                                <div class="input-group">
                                                    <span class="input-group-addon"><input type="checkbox" id="referenceCheckbox"></span>
                                                    <input type="text" class="form-control" id="referenceInput" placeholder="Optional" name="reference">
                                                </div>                                            
                                            </div>
                                        </div>
                                    </th>
                                </tr>
                                <tr>
                                    <th style="width:35%; text-align:center">FROM</th>
                                    <th style="width:35%; text-align:center">To</th>
                                </tr>
                                <tr>
                                    <td style="width:35%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12"> 
                                                <select class="form-control select" name="from_branch" onchange="showDis(this.value)">
                                                    <?php
                                                    $stmt = $pdo->prepare("SELECT * FROM branch ORDER BY name");
                                                    $stmt->execute();
                                                    $branches = $stmt->fetchAll(PDO::FETCH_ASSOC);
                                                    foreach ($branches as $branch) {
                                                        ?>
                                                        <option value="<?php echo $branch['name']; ?>"><?php echo $branch['name']; ?></option>
                                                        <?php
                                                    }
                                                    ?>
                                                </select>
                                            </div>
                                        </div>
                                    </td>
                                    <td style="width:35%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">
                                                <select class="form-control select" name="to_branch" onchange="showDis(this.value)">
                                                    <?php
                                                    $stmt = $pdo->prepare("SELECT * FROM branch ORDER BY name");
                                                    $stmt->execute();
                                                    $branches = $stmt->fetchAll(PDO::FETCH_ASSOC);
                                                    foreach ($branches as $branch) {
                                                        ?>
                                                        <option value="<?php echo $branch['name']; ?>"><?php echo $branch['name']; ?></option>
                                                        <?php
                                                    }
                                                    ?>
                                                </select>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <th colspan="2" style="width:70%">Transfer Description</th>
                                </tr>
                                <tr>
                                    <td colspan="2" style="width:70%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <textarea class="form-control" name="note" required></textarea>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <th style="width:35%">Item</th>
                                    <th style="width:20%">QOH</th>
                                    <th style="width:25%">Quantity</th>
                                </tr>
                                <tr>
                                    <td style="width:35%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">
                                                <?php
                                                $product = mysqli_query($con,"SELECT * FROM product ORDER BY Name ASC");
                                                ?>                     
                                                <select class="form-control select" data-live-search="true" name="item[]" required onchange="fetchProductQuantity(this)">
                                                    <option value="">Search Item Here</option>
                                                    <?php foreach($product as $rows): ?>
                                                    <option value="<?php echo $rows['ProductId'];?>"><?php echo $rows['Name'];?></option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                        </div>
                                    </td>
                                    <td style="width:20%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <input type="text" name="qah[]" class="form-control qah" style="width:100%" readonly />
                                            </div>
                                        </div>
                                    </td>
                                    <td style="width:25%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <input type="text" oninput="validateQuantity(this)" name="amount[]" class="form-control amount" style="width:100%" />
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <td>
                                        <button type="button" class="btn btn-primary" onclick="addAccountLine()" style="background-color: green;color: white;">Add Line</button>
                                    </td>
                                    <td colspan="2" align="right"><button class="btn btn-default" style="color:red;font-size:16px">Total Quantity: <span id="totalAmount">0.00</span></button></td>
                                </tr>
                            </tbody>    
                        </table>
                </div>
                <div class="panel-footer">
                    <button type="submit" id ="create" name="submit" class="btn btn-info pull-right"><span class="fa fa-plus-circle"></span> Create </button>
                </div>
                </form>
            </div>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>

<script>
    let voucherCounter = 1; // Initialize the voucher counter

    // Set default date to today
    document.getElementById('datePicker').valueAsDate = new Date();

    // Function to add a new account line
    function addAccountLine() {
        const tableBody = document.querySelector('.table tbody');

        const newRow = document.createElement('tr');
        newRow.innerHTML = `
            <td style="width:35%">
                <div class="form-group">
                    <div class="col-md-12 col-xs-12">
                        <?php
                        $product = mysqli_query($con,"SELECT * FROM product  ORDER BY Name ASC");
                        ?>                     
                        <select class="form-control select" data-live-search="true" name="item[]" required onchange="fetchProductQuantity(this)">
                            <option value="">Search Item Here</option>
                            <?php foreach($product as $rows): ?>
                            <option value="<?php echo $rows['ProductId'];?>"><?php echo $rows['Name'];?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
            </td>
            <td style="width:20%">
                <div class="form-group">
                    <div class="col-md-12 col-xs-12">                       
                        <input type="text" name="qah[]" class="form-control qah" style="width:100%" readonly />
                    </div>
                </div>
            </td>
            <td style="width:25%">
                <div class="form-group">
                    <div class="col-md-12 col-xs-12">                       
                        <input type="text" oninput="validateQuantity(this)" name="amount[]" class="form-control amount" style="width:100%" />
                    </div>
                </div>
            </td>
            <td style="background-color:#ffffff">
                <button class="btn btn-danger" onclick="removeAccountLine(this)"><i class="fa fa-trash-o"></i></button>
            </td>
        `;
        // Initialize Bootstrap Selectpicker for the first row
        $(newRow.querySelector('.select')).selectpicker();

        // Insert new row just above the "Add Line" and "Create" buttons
        tableBody.insertBefore(newRow, tableBody.lastElementChild);

        // Update the sum of amounts
        updateTotalAmount();
    }

    // Function to update the total amount
    function updateTotalAmount() {
        const amounts = document.querySelectorAll('input[name="amount[]"]');
        let total = 0;

        amounts.forEach(input => {
            total += parseFloat(input.value) || 0;
        });
        const formattedTotal = total.toLocaleString();
        // Display the total amount in an element with id "totalAmount"
        document.getElementById('totalAmount').innerText = formattedTotal;
    }

    // Function to remove an account line
    function removeAccountLine(button) {
        const row = button.closest('tr');
        row.remove();

        // Update the sum of amounts after removing the line
        updateTotalAmount();
    }

  
   function fetchProductQuantity(selectElement) {
    var productId = selectElement.value;
    var row = selectElement.closest('tr'); // Get the row of the select element
    var qahInput = row.querySelector('input[name="qah[]"]'); // Find the QAH input in the same row

    
    var xhr = new XMLHttpRequest();
    xhr.open('GET', 'fetch_product_quantity.php?productId=' + productId, true);
    xhr.onload = function () {
        if (xhr.status === 200) {
            var quantity = parseFloat(xhr.responseText);
            if (!isNaN(quantity)) {
                qahInput.value = quantity.toFixed(2); 
            } else {
                console.error('Invalid quantity received:', xhr.responseText);
                qahInput.value = '0.00';
            }
        } else {
            console.error('Error fetching quantity:', xhr.status, xhr.statusText);
            qahInput.value = '0.00';
        }
    };
    xhr.onerror = function () {
        console.error('Request error.');
        qahInput.value = '0.00';
    };
    xhr.send();
}




    // Validate the entered quantity against the available quantity
    function validateQuantity(amountInput) {
        const row = amountInput.closest('tr');
        const qahInput = row.querySelector('input[name="qah[]"]');
        const availableQuantity = parseFloat(qahInput.value) || 0;
        const enteredQuantity = parseFloat(amountInput.value) || 0;
        const btn =document.querySelector('#create');

        if (enteredQuantity > availableQuantity) {
            alert('The entered quantity is greater than the available quantity.');
            qahInput.style.color = 'red';
              btn.setAttribute('disabled', 'true');
            
        } else {
            qahInput.style.color = '';
             btn.removeAttribute('disabled');
        }

        // Update the total amount
        updateTotalAmount();
    }
</script>
