<?php
session_start();
include '../db/db.php';

// Check if ID is set
if (isset($_GET['id'])) {
    $id = $_GET['id'];

    // Fetch the transfer details
    $sql = "SELECT td.date, td.reference, td.from, td.to, td.notes, p.Name, ti.item_id, ti.quantity
            FROM transfer_details td
            LEFT JOIN transfer_items ti ON td.id = ti.transfer_id
            INNER JOIN product p ON ti.item_id = p.ProductId
            WHERE td.id = ?";
    
    $stmt = $pdo->prepare($sql);
    $stmt->execute([$id]);
    $transfer = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    if (empty($transfer)) {
        echo "Transfer not found.";
        exit;
    }

    // Handle form submission
    if (isset($_POST['submit'])) {
        // Get user ID from session
        $user_id = $_SESSION['id'];

        // Get form data
        $date = $_POST['date'];
        $reference = $_POST['reference'];
        $from_branch = $_POST['from_branch'];
        $to_branch = $_POST['to_branch'];
        $note = $_POST['note'];
        $items = $_POST['item'];
        $quantities = $_POST['amount'];

        // Update transfer details
        $stmt = $pdo->prepare("UPDATE transfer_details SET date = :date, reference = :reference, `from` = :from_branch, `to` = :to_branch, notes = :note WHERE id = :id");
        $stmt->execute([
            ':date' => $date,
            ':reference' => $reference,
            ':from_branch' => $from_branch,
            ':to_branch' => $to_branch,
            ':note' => $note,
            ':id' => $id
        ]);

        // Delete existing transfer items
        $stmt = $pdo->prepare("DELETE FROM transfer_items WHERE transfer_id = :transfer_id");
        $stmt->execute([':transfer_id' => $id]);

        // Insert updated transfer items
        for ($i = 0; $i < count($items); $i++) {
            $stmt = $pdo->prepare("INSERT INTO transfer_items (item_id, transfer_id, quantity) VALUES (:item_id, :transfer_id, :quantity)");
            $stmt->execute([
                ':item_id' => $items[$i],
                ':transfer_id' => $id,
                ':quantity' => $quantities[$i]
            ]);
        }

        // Redirect to a confirmation page or display a success message
        echo "<script>
            alert('Transfer has been successfully updated.');
            window.location.href='index.php?p=transfer';
        </script>";
    }
} else {
    echo "Invalid request.";
    exit;
}
?>

<div class="col-md-9">
    <!-- START TIMELINE -->
    <div class="row">
        <div class="col-md-12">
            <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=accounting" style="color: rgb(7, 133, 164)">Items Menu</a></li>
                <li><a href="index.php?p=transfer" style="color: rgb(7, 133, 164)">Transfer List</a></li>
                <li class="active">Edit Transfer</li>
            </ul>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>EDIT TRANSFER</b></h3>
                </div>
                <div class="panel-body">
                    <form class="form-horizontal" method="post" action="" enctype="multipart/form-data">           
                        <table class="table" style="width: 70%;">
                            <tbody>
                                <tr>
                                    <th style="width:35%">
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Date *</label>
                                            <div class="col-md-12 col-xs-12">            
                                                <input type="text" class="form-control datepicker" name="date" value="<?php echo $transfer[0]['date']; ?>" />            
                                            </div>
                                        </div> 
                                    </th>
                                    <th style="width:35%">
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Reference</label>
                                            <div class="col-md-12 col-xs-12">                       
                                                <div class="input-group">
                                                    <span class="input-group-addon"><input type="checkbox" id="referenceCheckbox"></span>
                                                    <input type="text" class="form-control" id="referenceInput" placeholder="Optional" name="reference" value="<?php echo $transfer[0]['reference']; ?>">
                                                </div>                                            
                                            </div>
                                        </div>
                                    </th>
                                </tr>
                                <tr>
                                    <th style="width:35%; text-align:center">FROM</th>
                                    <th style="width:35%; text-align:center">TO</th>
                                </tr>
                                <tr>
                                    <td style="width:35%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12"> 
                                                <select class="form-control select" name="from_branch">
                                                    <?php
                                                    $stmt = $pdo->prepare("SELECT * FROM branch ORDER BY name");
                                                    $stmt->execute();
                                                    $branches = $stmt->fetchAll(PDO::FETCH_ASSOC);
                                                    foreach ($branches as $branch) {
                                                        $selected = $branch['name'] == $transfer[0]['from'] ? 'selected' : '';
                                                        echo "<option value='{$branch['name']}' $selected>{$branch['name']}</option>";
                                                    }
                                                    ?>
                                                </select>
                                            </div>
                                        </div>
                                    </td>
                                    <td style="width:35%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">
                                                <select class="form-control select" name="to_branch">
                                                    <?php
                                                    foreach ($branches as $branch) {
                                                        $selected = $branch['name'] == $transfer[0]['to'] ? 'selected' : '';
                                                        echo "<option value='{$branch['name']}' $selected>{$branch['name']}</option>";
                                                    }
                                                    ?>
                                                </select>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <th colspan="2" style="width:70%">Transfer Description</th>
                                </tr>
                                <tr>
                                    <td colspan="2" style="width:70%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <textarea class="form-control" name="note" required><?php echo $transfer[0]['notes']; ?></textarea>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <th style="width:35%">Item</th>
                                    <th style="width:35%">Quantity</th>
                                </tr>
                                <?php
                                foreach ($transfer as $item) {
                                ?>
                                <tr>
                                    <td style="width:50%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">
                                                <select class="form-control select" data-live-search="true" name="item[]" required>
                                                    <option value="">Search Item Here</option>
                                                    <?php
                                                    $products = mysqli_query($con, "SELECT * FROM product WHERE Category='Finished goods' ORDER BY Name ASC");
                                                    foreach ($products as $product) {
                                                        $selected = $product['ProductId'] == $item['item_id'] ? 'selected' : '';
                                                        echo "<option value='{$product['ProductId']}' $selected>{$product['Name']}</option>";
                                                    }
                                                    ?>
                                                </select>
                                            </div>
                                        </div>
                                    </td>
                                    <td style="width:35%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <input type="text" name="amount[]" class="form-control" value="<?php echo $item['quantity']; ?>" oninput="updateTotalAmount()" />
                                            </div>
                                        </div>
                                    </td>
                                    <td style="background-color:#ffffff">
                                        <button class="btn btn-danger" onclick="removeAccountLine(this)"><i class="fa fa-trash-o"></i></button>
                                    </td>
                                </tr>
                                <?php
                                }
                                ?>
                                <tr>
                                    <td>
                                        <span><button type="button" class="btn btn-primary" onclick="addAccountLine()" style="background-color: green;color: white;">Add Line</button></span>
                                    </td>
                                    <td colspan="2" align="right"><button class="btn btn-default" style="color:red;font-size:16px">Total Quantity: <span id="totalAmount">0.00</span></button></td>
                                </tr>
                            </tbody>    
                        </table>
                    
                </div>
                <div class="panel-footer">
                    <button type="submit" name="submit" class="btn btn-info pull-right"><span class="fa fa-plus-circle"></span> Update </button>
                </div>
                </form>
            </div>
            
        </div>
    </div>
    <!-- END TIMELINE -->
</div>

<script>
    let voucherCounter = 1; // Initialize the voucher counter

    // Set default date to today
    document.getElementById('datePicker').valueAsDate = new Date();

    // Function to add a new account line
    function addAccountLine() {
        const tableBody = document.querySelector('.table tbody');

        const newRow = document.createElement('tr');
        newRow.innerHTML = `
            <td style="width:50%">
                <div class="form-group">
                    <div class="col-md-12 col-xs-12">
                        <select class="form-control select" data-live-search="true" name="item[]" required>
                            <option value="">Search Item Here</option>
                            <?php
                            $products = mysqli_query($con, "SELECT * FROM product WHERE Category='Finished goods' ORDER BY Name ASC");
                            foreach ($products as $product) {
                                echo "<option value='{$product['ProductId']}'>{$product['Name']}</option>";
                            }
                            ?>
                        </select>
                    </div>
                </div>
            </td>
            <td style="width:50%">
                <div class="form-group">
                    <div class="col-md-12 col-xs-12">
                        <input type="text" name="amount[]" class="form-control" oninput="updateTotalAmount()" />
                    </div>
                </div>
            </td>
            <td style="background-color:#ffffff">
                <button class="btn btn-danger" onclick="removeAccountLine(this)"><i class="fa fa-trash-o"></i></button>
            </td>
        `;
        // Initialize Bootstrap Selectpicker for the first row
        $(newRow.querySelector('.select')).selectpicker();

        // Insert new row just above the "Add Line" and "Create" buttons
        tableBody.insertBefore(newRow, tableBody.lastElementChild);

        // Update the sum of amounts
        updateTotalAmount();
    }

    // Function to update the total amount
    function updateTotalAmount() {
        const amounts = document.querySelectorAll('input[name="amount[]"]');
        let total = 0;

        amounts.forEach(input => {
            total += parseFloat(input.value) || 0;
        });
        const formattedTotal = total.toLocaleString();
        // Display the total amount in an element with id "totalAmount"
        document.getElementById('totalAmount').innerText = formattedTotal;
    }

    // Function to remove an account line
    function removeAccountLine(button) {
        const row = button.closest('tr');
        row.remove();

        // Update the sum of amounts after removing the line
        updateTotalAmount();
    }
</script>

<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
