<?php
session_start();
include '../../db/db.php';

$id = $_GET['id'] ?? 0; // Get the stockout ID from the URL

if ($id == 0) {
    echo "<script>
        alert('Invalid stockout ID.');
        window.location.href='index.php?p=item_stock_out';
    </script>";
    exit();
}

if (isset($_POST['submit'])) {
    // Validate form data
    $date = $_POST['date'];
    $batchno = $_POST['batchno'];
    $providedto = $_POST['user'];
    $note = $_POST['note'];
    $branch = $_SESSION['Branch'];

    try {
        // Update data in stockout table
        $stmt = $pdo->prepare("UPDATE stockout SET date = :date, reference = :reference, providedto = :providedto, notes = :notes, branch = :branch WHERE id = :id");
        $stmt->execute([
            ':id' => $id,
            ':date' => $date,
            ':reference' => $batchno,
            ':providedto' => $providedto,
            ':notes' => $note,
            ':branch' => $branch
        ]);

        // Fetch existing items to adjust quantities in the product table
        $stmtItems = $pdo->prepare("SELECT * FROM stockout_items WHERE stockoutid = :stockout_id");
        $stmtItems->execute([':stockout_id' => $id]);
        $currentItems = $stmtItems->fetchAll(PDO::FETCH_ASSOC);

        // Restore the original quantities in the product table
        foreach ($currentItems as $currentItem) {
            $restoreStmt = $pdo->prepare("UPDATE product SET quantity = quantity + :quantity WHERE ProductId = :productid");
            $restoreStmt->execute([
                ':quantity' => $currentItem['quantity'],
                ':productid' => $currentItem['itemid']
            ]);
        }

        // Delete existing stockout_items
        $stmt = $pdo->prepare("DELETE FROM stockout_items WHERE stockoutid = :stockout_id");
        $stmt->execute([':stockout_id' => $id]);

        // Insert new stockout items and update product quantities
        foreach ($_POST['item'] as $index => $item) {
            $quantity = $_POST['amount'][$index];
            $cost = $_POST['cost'][$index];

            // Insert new items
            $stmt = $pdo->prepare("INSERT INTO stockout_items (itemid, stockoutid, quantity, cost) VALUES (:item_id, :stockout_id, :quantity, :cost)");
            $stmt->execute([
                ':item_id' => $item,
                ':stockout_id' => $id,
                ':quantity' => $quantity,
                ':cost' => $cost
            ]);

            // Update product quantity after stocking out
            $updateStmt = $pdo->prepare("UPDATE product SET quantity = quantity - :quantity WHERE ProductId = :productid");
            $updateStmt->execute([
                ':quantity' => $quantity,
                ':productid' => $item
            ]);
        }

        echo "<script>
            alert('Stock out updated successfully!');
            window.location.href='index.php?p=item_stock_out';
        </script>";
    } catch (PDOException $e) {
        echo "<script>
            alert('Error: " . htmlspecialchars($e->getMessage()) . "');
            window.location.href='index.php?p=item_stock_out_edit&id={$id}';
        </script>";
    }
}

// Fetch stockout data
$stmt = $pdo->prepare("SELECT * FROM stockout WHERE id = :id");
$stmt->execute([':id' => $id]);
$stockout = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$stockout) {
    echo "<script>
        alert('Stockout not found.');
        window.location.href='index.php?p=item_stock_out';
    </script>";
    exit();
}

// Fetch stockout items
$stmt = $pdo->prepare("SELECT * FROM stockout_items WHERE stockoutid = :stockout_id");
$stmt->execute([':stockout_id' => $id]);
$stockout_items = $stmt->fetchAll(PDO::FETCH_ASSOC);

?>

<div class="col-md-9">
    
    <div class="row">
        <div class="col-md-12">
            <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=item_menu" style="color: rgb(7, 133, 164)">Items Menu</a></li>
                <li><a href="index.php?p=item_stock_out" style="color: rgb(7, 133, 164)">Stock Out List</a></li>
                <li class="active">Edit Stock Out</li>
            </ul>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>STOCK OUT FORM</b></h3>
                </div>
                <div class="panel-body">
                    <form class="form-horizontal" method="post" action="" enctype="multipart/form-data">           
                        <table class="table">
                            <tbody>
                                <tr>
                                    <th>
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Date *</label>
                                            <div class="col-md-12 col-xs-12">            
                                                <input type="text" class="form-control datepicker" name="date" value="<?php echo $stockout['date']; ?>" />            
                                            </div>
                                        </div> 
                                    </th>
                                    <th>
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Issued By</label>
                                            <div class="col-md-12 col-xs-12"> 
                                                <select class="form-control select" name="user" onchange="showDis(this.value)">
                                                    <?php
                                                    $stmt = $pdo->prepare("SELECT * FROM inv_users");
                                                    $stmt->execute();
                                                    $users = $stmt->fetchAll(PDO::FETCH_ASSOC);
                                                    foreach ($users as $rows) {
                                                        $selected = ($rows['Name'] == $stockout['providedto']) ? 'selected' : '';
                                                        echo "<option value=\"{$rows['Name']}\" $selected>{$rows['Name']}</option>";
                                                    }
                                                    ?>
                                                </select>
                                            </div>
                                        </div>
                                    </th>
                                    <th>
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Production Batch No.</label>
                                            <div class="col-md-12 col-xs-12"> 
                                                <select class="form-control select" name="batchno" onchange="showDis(this.value)">
                                                    <?php
                                                    $stmt = $pdo->prepare("SELECT * FROM production WHERE branch = :branch");
                                                    $stmt->execute([':branch' => $_SESSION['Branch']]);
                                                    $production = $stmt->fetchAll(PDO::FETCH_ASSOC);
                                                    foreach ($production as $rows) {
                                                        $selected = ($rows['batch_id'] == $stockout['reference']) ? 'selected' : '';
                                                        echo "<option value=\"{$rows['batch_id']}\" $selected>Batch no. #{$rows['batch_id']} - {$rows['category']}</option>";
                                                    }
                                                    ?>
                                                </select>
                                            </div>
                                        </div>
                                    </th>
                                </tr>
                                <tr>
                                    <th colspan="3">Description *</th>
                                </tr>
                                <tr>
                                    <td colspan="3">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <textarea class="form-control" name="note" required><?php echo $stockout['notes']; ?></textarea>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <th>Item</th>
                                    <th>QOH</th>
                                    <th>Quantity</th>
                                    <th>Cost</th>
                                </tr>
                                <?php foreach ($stockout_items as $index => $item) : ?>
                                <tr>
                                    <td>
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">
                                                <?php
                                                $product = mysqli_query($con,"SELECT * FROM product ORDER BY Name ASC");
                                                ?>                     
                                                <select  class="form-control select" data-live-search="true" name="item[]" required onchange="fetchProductQuantity(this);fetchProductPrice(this)">
                                                    <option value="">Search Item Here</option>
                                                    <?php foreach($product as $rows): ?>
                                                    <option value="<?php echo $rows['ProductId'];?>" <?php echo ($rows['ProductId'] == $item['itemid']) ? 'selected' : ''; ?>><?php echo $rows['Name'];?></option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <input type="text" class="form-control" name="quantity[]" readonly />
                                            </div>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <input type="text" oninput="validateQuantity(this)" name="amount[]" class="form-control" value="<?php echo $item['quantity']; ?>" />
                                            </div>
                                        </div>
                                    </td>
                                      <td>
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <input type="text" id="cost" name="cost[]" class="form-control" value="<?php echo $item['cost']; ?>" />
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                                <tr>
                                    <td>
                                        <button type="button" class="btn btn-primary" onclick="addAccountLine()" style="background-color: green;color: white;">Add Line</button>
                                    </td>
                                    <td colspan="2" align="right"></td>
                                </tr>
                            </tbody>    
                        </table>
                </div>
                <div class="panel-footer">
                    <button type="submit" id="butsave" name="submit" class="btn btn-primary pull-right" style="background-color: green;color: white;">Update</button>                                    
                </div>
            </div>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>
</form>
            </div>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>
<script>
    let voucherCounter = 1; // Initialize the voucher counter

    // Set default date to today
    document.getElementById('datePicker').valueAsDate = new Date();

    // Function to add a new account line
    function addAccountLine() {
        const tableBody = document.querySelector('.table tbody');

        const newRow = document.createElement('tr');
        newRow.innerHTML = `
            <td>
            <div class="form-group">
                <div class="col-md-12 col-xs-12">
                    <?php
                    $product = mysqli_query($con, "SELECT * FROM product ORDER BY Name ASC");
                    ?>                     
                    <select class="form-control select" data-live-search="true" name="item[]" required onchange="fetchProductQuantity(this);fetchProductPrice(this)">
                        <option value="">Search Item Here</option>
                        <?php foreach ($product as $rows): ?>
                        <option value="<?php echo $rows['ProductId']; ?>"><?php echo $rows['Name']; ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </div>
        </td>
            <td>
            <div class="form-group">
                <div class="col-md-12 col-xs-12">                       
                    <input type="text" class="form-control" name="quantity[]" readonly />
                </div>
            </div>
        </td>
            <td>
            <div class="form-group">
                <div class="col-md-12 col-xs-12">                       
                    <input type="text" oninput="validateQuantity(this)" name="amount[]" class="form-control" />
                </div>
            </div>
        </td>
            <td>
            <div class="form-group">
                <div class="col-md-12 col-xs-12">                       
                    <input type="text" id="cost" name="cost[]" class="form-control" />
                </div>
            </div>
        </td>
            <td style="background-color:#ffffff">
                <button class="btn btn-danger" onclick="removeAccountLine(this)"><i class="fa fa-trash-o"></i></button>
            </td>
        `;
        // Initialize Bootstrap Selectpicker for the first row
        $(newRow.querySelector('.select')).selectpicker();

        // Insert new row just above the "Add Line" and "Create" buttons
        tableBody.insertBefore(newRow, tableBody.lastElementChild);

        // Update the sum of amounts
        updateTotalAmount();
    }

    // Function to update the total amount
    function updateTotalAmount() {
        const amounts = document.querySelectorAll('input[name="amount[]"]');
        let total = 0;

        amounts.forEach(input => {
            total += parseFloat(input.value) || 0;
        });
        const formattedTotal = total.toLocaleString();
        // Display the total amount in an element with id "totalAmount"
        document.getElementById('totalAmount').innerText = formattedTotal;
    }

    // Function to remove an account line
    function removeAccountLine(button) {
        const row = button.closest('tr');
        row.remove();

        // Update the sum of amounts after removing the line
        updateTotalAmount();
    }
</script>

<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
<script>
$(document).ready(function(){
    // Call fetchProductQuantity and fetchProductPrice for each existing product
    $('select[name="item[]"]').each(function() {
        fetchProductQuantity(this);
        fetchProductPrice(this);
    });
});

function fetchProductQuantity(element) {
    var productId = $(element).val();
    var quantityInput = $(element).closest('tr').find('input[name="quantity[]"]');
    $.ajax({
        url: "fetch_product_quantity.php",
        method: "GET",
        data: { productId: productId },
        success: function(data) {
            quantityInput.val(data);
        }
    });
}

function fetchProductPrice(element) {
    var productId = $(element).val();
    var costInput = $(element).closest('tr').find('input[name="cost[]"]');
    $.ajax({
        url: "get_product_cost.php",
        method: "GET",
        data: { productId: productId },
        success: function(data) {
            costInput.val(data);
        }
    });
}

function validateQuantity(input) {
    var max = parseFloat($(input).closest('tr').find('input[name="quantity[]"]').val());
    var value = parseFloat($(input).val());
    if (value > max) {
        alert("Quantity cannot be more than " + max);
        $(input).val(max);
    }
}
</script>