<?php
session_start();
include '../db/db.php';

if (isset($_POST['submit'])) {
    // Validate form data
    $date = filter_var($_POST['date'], FILTER_SANITIZE_STRING);
    $reference = filter_var($_POST['reference'], FILTER_SANITIZE_STRING);
    $note = filter_var($_POST['note'], FILTER_SANITIZE_STRING);
    $items = array_map('intval', $_POST['item']);
    $quantities = array_map('intval', $_POST['amount']);
    $costs = array_map('intval', $_POST['cost']);

    if (empty($date) || empty($items) || empty($quantities)) {
        echo "<script>
            Swal.fire({
                icon: 'error',
                title: 'Validation Error',
                text: 'All fields are required.',
            }).then(() => {
                window.location.href = 'index.php?p=write_off_add';
            });
        </script>";
        exit;
    }

    $user_id = $_SESSION['id'];
    $branch = $_SESSION['Branch'];

    try {
        // Insert into writeoff table
        $stmt = $pdo->prepare("INSERT INTO writeoff (date, reference, user, notes, branch) 
                               VALUES (:date, :reference, :user, :notes, :branch)");
        $stmt->execute([
            ':date' => $date,
            ':reference' => $reference,
            ':notes' => $note,
            ':user' => $user_id,
            ':branch' => $branch
        ]);

        $writeoff_id = $pdo->lastInsertId();

        $totalCost = 0;
        for ($i = 0; $i < count($items); $i++) {
            $stmt = $pdo->prepare("INSERT INTO writeoff_items (writeoff_id, itemid, quantity, cost) 
                                   VALUES (:writeoff_id, :itemid, :quantity, :cost)");
            $stmt->execute([
                ':writeoff_id' => $writeoff_id,
                ':itemid' => $items[$i],
                ':quantity' => $quantities[$i],
                ':cost' => $costs[$i]
            ]);

            $totalCost += $quantities[$i] * $costs[$i];
            
           // $stmt1 = $pdo->prepare("UPDATE product SET Quantity=Quantity-:quantity WHERE ProductId=:itemid");
           // $result1 = $stmt1->execute([
              //  ':itemid' => $items[$i],
              //  ':quantity' => $quantities[$i]
             //]);
        }

        // GL transactions (using mysqli for legacy code)
        $debit = mysqli_query($con, "SELECT * FROM chart_master WHERE account_code='1340'");
        $row_db = mysqli_fetch_array($debit);
        $fslidb = $row_db['account_type'];
        $class_db = $row_db['class'];

        $credit = mysqli_query($con, "SELECT * FROM chart_master WHERE account_code='5099'");
        $row_cr = mysqli_fetch_array($credit);
        $fslicr = $row_cr['account_type'];
        $class_cr = $row_cr['class'];

        mysqli_query($con, "INSERT INTO gl_transaction 
                            VALUES('', '1340', '$fslidb', '$class_db', '$totalCost', 'Credit', '', 
                                   '{$_SESSION['id']}', 'Inventory Write Off', '', '$date', 
                                   '{$_SESSION['Branch']}', 'Write Off')");

        mysqli_query($con, "INSERT INTO gl_transaction 
                            VALUES('', '5099', '$fslicr', '$class_cr', '$totalCost', 'Debit', '', 
                                   '{$_SESSION['id']}', 'Inventory Write Off', '', '$date', 
                                   '{$_SESSION['Branch']}', 'Write Off')");

        echo "<script>
            Swal.fire({
                icon: 'success',
                title: 'Writeoff Added',
                text: 'Writeoff has been successfully added.',
            }).then(() => {
                window.location.href = 'index.php?p=write_off';
            });
        </script>";
    } catch (PDOException $e) {
        echo "<script>
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: '" . htmlspecialchars($e->getMessage()) . "',
            }).then(() => {
                window.location.href = 'index.php?p=write_off_add';
            });
        </script>";
    }
}
?>


<div class="col-md-9">
    <!-- START TIMELINE -->
    <div class="row">
        <div class="col-md-12">
            <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=accounting" style="color: rgb(7, 133, 164)">Items Menu</a></li>
                <li><a href="index.php?p=write_off" style="color: rgb(7, 133, 164)">writeoff List</a></li>
                <li class="active">Add writeoff</li>
            </ul>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>ADD WRITEOFF</b></h3>
                </div>
                <div class="panel-body">
                    <form class="form-horizontal" method="post" action="" enctype="multipart/form-data">           
                       <table class="table" style="width: 90%;">
                            <tbody>
                                <tr>
                                    <th style="width:45%" colspan=2>
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Date *</label>
                                            <div class="col-md-12 col-xs-12">            
                                                <input type="text" class="form-control datepicker" name="date" value="<?php echo date('Y-m-d');?>" />            
                                            </div>
                                        </div> 
                                    </th>
                                    <th style="width:45%">
                                        <div class="form-group">
                                            <label class="col-md-12 col-xs-12">Reference</label>
                                            <div class="col-md-12 col-xs-12">                       
                                                <div class="input-group">
                                                    <span class="input-group-addon"><input type="checkbox" id="referenceCheckbox"></span>
                                                    <input type="text" class="form-control" id="referenceInput" placeholder="Optional" name="reference">
                                                </div>                                            
                                            </div>
                                        </div>
                                    </th>
                                </tr>
                                <tr>
                                    <th colspan="3" style="width:90%">Transfer Description</th>
                                </tr>
                                <tr>
                                    <td colspan="3" style="width:90%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <textarea class="form-control" name="note" required></textarea>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <th style="width:30%">Item</th>
                                    <th style="width:30%">Cost</th>
                                    <th style="width:30%">Quantity</th>
                                </tr>
                                <tr>
                                    <td style="width:35%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">
                                                <?php
                                                $product = mysqli_query($con,"SELECT * FROM product WHERE Category = 'Product' ORDER BY Name ASC");
                                                ?>                     
                                                <select class="form-control select" data-live-search="true" name="item[]" required onchange="fetchProductPrice(this)">
                                                    <option value="">Search Item Here</option>
                                                    <?php foreach($product as $rows): ?>
                                                    <option value="<?php echo $rows['ProductId'];?>"><?php echo $rows['Name'];?></option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                        </div>
                                    </td>
                                    <td style="width:20%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                                <input type="text" name="cost[]" class="form-control" style="width:100%" />
                                            </div>
                                        </div>
                                    </td>
                                    <td style="width:25%">
                                        <div class="form-group">
                                            <div class="col-md-12 col-xs-12">                       
                                        <input type="text" oninput="updateTotalAmount()" name="amount[]" class="form-control" style="width:100%" />
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <td>
                                        <button type="button" class="btn btn-primary" onclick="addAccountLine()" style="background-color: green;color: white;">Add Line</button>
                                    </td>
                                    <td colspan="2" align="right"><button class="btn btn-default" style="color:red;font-size:16px">Total Value: <span id="totalAmount">0.00</span></button></td>
                                </tr>
                            </tbody>    
                        </table>
                </div>
                <div class="panel-footer">
                    <button type="submit" name="submit" class="btn btn-info pull-right"><span class="fa fa-plus-circle"></span> Create </button>
                </div>
                </form>
            </div>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>
<script>
    let voucherCounter = 1; // Initialize the voucher counter

    // Set default date to today
    document.getElementById('datePicker').valueAsDate = new Date();

    // Function to add a new account line
    function addAccountLine() {
        const tableBody = document.querySelector('.table tbody');

        const newRow = document.createElement('tr');
        newRow.innerHTML = `
            <td style="width:35%">
                <div class="form-group">
                    <div class="col-md-12 col-xs-12">
                        <?php
                        $product = mysqli_query($con,"SELECT * FROM product WHERE Category = 'Product'  ORDER BY Name ASC");
                        ?>                     
                        <select class="form-control select" data-live-search="true" name="item[]" required onchange="fetchProductPrice(this)">
                            <option value="">Search Item Here</option>
                            <?php foreach($product as $rows): ?>
                            <option value="<?php echo $rows['ProductId'];?>"><?php echo $rows['Name'];?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
            </td>
            <td style="width:20%">
                <div class="form-group">
                    <div class="col-md-12 col-xs-12">                       
                        <input type="text" name="cost[]" class="form-control" style="width:100%" />
                    </div>
                </div>
            </td>
            <td style="width:25%">
                <div class="form-group">
                    <div class="col-md-12 col-xs-12">                       
                        <input type="text" oninput="updateTotalAmount()" name="amount[]" class="form-control" style="width:100%" />
                    </div>
                </div>
            </td>
            <td style="background-color:#ffffff">
                <button class="btn btn-danger" onclick="removeAccountLine(this)"><i class="fa fa-trash-o"></i></button>
            </td>
        `;
        // Initialize Bootstrap Selectpicker for the first row
        $(newRow.querySelector('.select')).selectpicker();

        // Insert new row just above the "Add Line" and "Create" buttons
        tableBody.insertBefore(newRow, tableBody.lastElementChild);

        // Update the sum of amounts
        updateTotalAmount();
    }

    // Function to update the total amount
   function updateTotalAmount() {
    const amounts = document.querySelectorAll('input[name="amount[]"]');
    const costs = document.querySelectorAll('input[name="cost[]"]');
    let total = 0;

    // Loop through each item and calculate the total based on amount and cost
    amounts.forEach((amountInput, index) => {
        const amount = parseFloat(amountInput.value) || 0;
        const cost = parseFloat(costs[index].value) || 0;
        total += amount * cost;
    });

    // Format the total to include commas for thousands and ensure two decimal places
    const formattedTotal = total.toLocaleString(undefined, { minimumFractionDigits: 2, maximumFractionDigits: 2 });

    // Display the total amount in the element with id "totalAmount"
    document.getElementById('totalAmount').innerText = formattedTotal;
   }

    // Function to remove an account line
    function removeAccountLine(button) {
        const row = button.closest('tr');
        row.remove();

        // Update the sum of amounts after removing the line
        updateTotalAmount();
    }
</script>
<script>
    function fetchProductPrice(selectElement) {
            var productId = selectElement.value;
            var row = selectElement.closest('tr'); // Get the row of the select element
            var amountInput = row.querySelector('input[name="cost[]"]'); // Find the amount input in the same row

            // Send AJAX request to fetch product price
            var xhr = new XMLHttpRequest();
            xhr.open('GET', 'get_product_cost.php?productId=' + productId, true);
            xhr.onload = function () {
                if (xhr.status === 200) {
                    var price = parseFloat(xhr.responseText);
                    if (!isNaN(price)) {
                        amountInput.value = price.toFixed(2); 
                    }
                }
            };
            xhr.send();
        }
</script>

<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
<script>
  $(document).ready(function() {
    $('#payeeType').change(function() {
      if ($(this).val() === 'customer') {
        $('#payeeInputWrapper').hide();
        $('#payeeSelect').show();