<?php
if (isset($_GET['month']) && isset($_GET['year'])) {
    $month = $_GET['month'];
    $year = $_GET['year'];
    $option = isset($_GET['option']) ? $_GET['option'] : ''; // Ensure $option is set

    try {
        // Fetch payroll data using a prepared statement
        $stmt = $pdo->prepare("
            SELECT 
                pe.*, 
                er.Fname, er.Lname, er.Bank_Name,
                er.Bank_Account_No, 
                er.TIN, 
                er.trade_union_type, 
                er.trade_union_amount,
                er.nhif_number,
                er.fund_type,
                er.fund_number,
                er.fund_employee_per,
                er.fund_employer_per,
                er.employer_nhif_per,
                er.employee_nhif_per
                
                
            FROM 
                payroll_employees pe 
            INNER JOIN 
                Employee_Registration er ON pe.employeeId = er.id 
            INNER JOIN 
                payroll pa ON pa.id = pe.payrollId
            WHERE 
                pa.payrollMonth = :month AND pa.year = :year
        ");
        $stmt->execute(['month' => $month, 'year' => $year]);
        $payrollData = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
    } catch (Exception $e) {
        echo "Error: " . $e->getMessage();
    }
}
?>
<style>
    /* CSS to style the table */
    table {
        border-collapse: collapse;
        border: 1px solid black; /* Set border color and thickness */
        width: 100%; /* Set table width to 100% of its container */
    }

    th, td {
        border: 1px solid black; /* Set border for table cells */
        padding: 8px; /* Add padding for better readability */
        height: 20px;
        color: black;
        text-align: center; /* Center-align text within cells */
    }
</style>
<div class="col-md-9">
    <!-- START TIMELINE -->
    <div class="row">
        <div class="col-md-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>OTHER PAYROLL REPORTS</b></h3>
                    <div class="pull-right">
                        <button class="btn btn-default" onclick="history.back()"> <span class="fa fa-arrow-left"></span> Go Back</button>
                        <button class="btn btn-default" onclick="printContent()">
                            <span class="fa fa-print"></span> Print Report
                        </button>
                        <button class="btn btn-default" onclick="exportToExcel()">
                            <span class="fa fa-download"></span> Export To Excel
                        </button>
                    </div>
                </div>
                <div class="panel-body" style="background: #fff">
                    <div id="printingArea">
                        <?php if ($option == 'NSSF'): ?>
                        <table id="myTable">
                            <tr>
                                <th colspan="8"><?php echo $_SESSION['Company']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="8">BRANCH: <?php echo $_SESSION['Branch']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="8">PENSION REPORT</th>
                            </tr>
                            <tr>
                                <th>#</th>
                                <th>Name</th>
                                <th>Pension No.</th>
                                <th>Gross Pay</th>
                                <th>Pension type</th>
                                <th>Employee Contribution</th>
                                <th>Employer Contribution</th>
                                <th>Total Pension</th>
                            </tr>
                            <?php foreach ($payrollData as $index => $row): 
                                
                                $grossSalary=$row['grossSalary'];
                                $pensionEmployer = $row['grossSalary'] * $row['fund_employer_per']/100;
                                $pensionEmployee = $row['grossSalary'] * $row['fund_employee_per']/100;
                            ?>
                          
                            <tr>
                                <td><?php echo $index + 1; ?></td>
                                <td><?php echo $row['Fname'] . ' ' . $row['Lname']; ?></td>
                                <td><?php echo $row['fund_number']; ?></td>
                                <td><?php echo number_format($row['grossSalary'], 2); ?></td>
                                <td><?php echo $row['fund_type']; ?></td>
                                <td><?php echo number_format($pensionEmployee, 2); ?></td>
                                <td><?php echo number_format($pensionEmployer, 2); ?></td>
                                <td><?php echo number_format($pensionEmployer + $pensionEmployee, 2); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </table>
                        <?php elseif ($option == 'PAYESDL'): ?>
                        <table id="myTable">
                            <tr>
                                <th colspan="9"><?php echo $_SESSION['Company']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="9">BRANCH: <?php echo $_SESSION['Branch']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="9">LIST OF STAFFS FOR PAYE AND SDL PAYMENTS</th>
                            </tr>
                            <tr>
                                <th>#</th>
                                <th>Employee TIN</th>
                                <th>Name</th>
                                <th>Gross Pay</th>
                                <th>PENSION</th>
                                <th>NHIF</th>
                                <th>Taxable Income</th>
                                <th>PAYE</th>
                                <th>SDL (Payroll Levy)</th>
                            </tr>
                            <?php foreach ($payrollData as $index => $row): ?>
                            <tr>
                                <td><?php echo $index + 1; ?></td>
                                <td><?php echo $row['TIN']; ?></td>
                                <td><?php echo $row['Fname'] . ' ' . $row['Lname']; ?></td>
                                <td><?php echo number_format($row['grossSalary'], 2); ?></td>
                                <td><?php echo number_format($row['pension'], 2); ?></td>
                                <td><?php echo number_format($row['insuarance'], 2); ?></td>
                                <td><?php echo number_format($row['grossSalary'] - ($row['pension'] + $row['nhif']), 2); ?></td>
                                <td><?php echo number_format($row['paye'], 2); ?></td>
                                <td><?php echo number_format($row['sdl'], 2); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </table>
                        <?php elseif ($option == 'WCF'): ?>
                        <table id="myTable">
                            <tr>
                                <th colspan="5"><?php echo $_SESSION['Company']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="5">BRANCH: <?php echo $_SESSION['Branch']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="5">LIST OF STAFFS FOR WCF PAYMENTS</th>
                            </tr>
                            <tr>
                                <th>#</th>
                                <th>Employee No.</th>
                                <th>Name</th>
                                <th>Gross Pay</th>
                                <th>WCF Payment</th>
                            </tr>
                            <?php foreach ($payrollData as $index => $row): ?>
                            
                            <tr>
                                <td><?php echo $index + 1; ?></td>
                                <td><?php echo $row['employeeId']; ?></td>
                                <td><?php echo $row['Fname'] . ' ' . $row['Lname']; ?></td>
                                <td><?php echo number_format($row['grossSalary'], 2); ?></td>
                                <td><?php echo number_format($row['wcf'], 2); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </table>
                        <?php elseif ($option == 'TRADEUNION'): ?>
                        <table id="myTable">
                            <tr>
                                <th colspan="6"><?php echo $_SESSION['Company']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="6">BRANCH: <?php echo $_SESSION['Branch']; ?></th>
                            </tr>
                            <tr>
                                <th colspan="6">LIST OF STAFFS FOR TRADE UNION PAYMENTS</th>
                            </tr>
                            <tr>
                                <th>#</th>
                                <th>Employee No.</th>
                                <th>Name</th>
                                <th>Trade Union</th>
                                <th>Basic Salary</th>
                                <th>Trade Union Amount</th>
                            </tr>
                            <?php foreach ($payrollData as $index => $row): ?>
                            <tr>
                                <td><?php echo $index + 1; ?></td>
                                <td><?php echo $row['employeeId']; ?></td>
                                <td><?php echo $row['Fname'] . ' ' . $row['Lname']; ?></td>
                                <td><?php echo $row['trade_union_type']; ?></td>
                                <td><?php echo number_format($row['grossSalary'], 2); ?></td>
                                <td><?php echo number_format($row['tradeUnion'], 2); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </table>
                        <?php else: ?>
                        <p>No report selected.</p>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="panel-footer">
                </div>
            </div>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>
<script>
    function printContent() {
        var content = document.getElementById('printingArea').innerHTML;
        var printWindow = window.open('', '_blank');
        printWindow.document.write('<html><head><title>Print</title>');
        printWindow.document.write('<style>table { border-collapse: collapse; border: 1px solid black; width: 100%; } th, td { border: 1px solid black; padding: 8px; text-align: center; height: 20px; color: black; } a { color: black; text-decoration: none; } </style>');
        printWindow.document.write('</head><body>');
        printWindow.document.write(content);
        printWindow.document.write('</body></html>');
        printWindow.document.close();
        printWindow.print();
    }

    function exportToExcel() {
        var table = document.getElementById('printingArea'); // Replace 'tableId' with the ID of your table
        var wb = XLSX.utils.table_to_book(table);
        var wbout = XLSX.write(wb, { bookType: 'xlsx', type: 'binary' });
        var blob = new Blob([s2ab(wbout)], { type: 'application/octet-stream' });
        var link = document.createElement('a');
        link.href = window.URL.createObjectURL(blob);
        link.download = 'payroll_report.xlsx'; // Change 'filename' to your desired filename
        link.click();
    }

    function s2ab(s) {
        var buf = new ArrayBuffer(s.length);
        var view = new Uint8Array(buf);
        for (var i = 0; i < s.length; i++) {
            view[i] = s.charCodeAt(i) & 0xFF;
        }
        return buf;
    }
</script>