<?php
require_once '../db/db.php'; // Include your database connection file

// Check if the ID is set in the URL
if (isset($_GET['id'])) {
    $id = $_GET['id'];
    
    // Fetch the existing data for the allowance
    $stmt = $pdo->prepare("SELECT * FROM allowances WHERE id = :id");
    $stmt->execute([':id' => $id]);
    $allowance = $stmt->fetch();
    
}

    // If the form is submitted, update the allowance
    if (isset($_POST['submit'])) {
           $employeeName = mysqli_real_escape_string($con, $_POST['employeeName']);
            $amount = mysqli_real_escape_string($con, $_POST['amount']);
            $date = mysqli_real_escape_string($con, $_POST['date']);
            $category = mysqli_real_escape_string($con, $_POST['category']);
    
        $timestamp = strtotime($date);  
        $month = date('n', $timestamp); // Get numeric month (1-12)
        $year = date('Y', $timestamp);  // Get year (e.g., 2024)
        
        // Update the allowance in the database
        $stmt = $pdo->prepare("UPDATE allowances 
                               SET employee_id = :employee_id, 
                                   category = :category, 
                                   amount = :amount, 
                                   date = :date, 
                                   month = :month, 
                                   year = :year 
                               WHERE id = :id");
        $result = $stmt->execute([
            ':employee_id' => $employeeName,
            ':category' => $category,
            ':amount' => $amount,
            ':date' => $date,
            ':month' => $month,
            ':year' => $year,
            ':id' => $id
        ]);
    
        // Check if the update was successful
        if ($result) {
            $err = '<div class="alert alert-success" role="alert">
                        <button type="button" class="close" data-dismiss="alert">&times;</button>
                        Allowance updated successfully.
                    </div>';
        } else {
            $err = '<div class="alert alert-danger" role="alert">
                        <button type="button" class="close" data-dismiss="alert">&times;</button>
                        Error updating allowance. Please try again.
                    </div>';
        }
    }

?>

<div class="col-md-9">
 <div class="row">
    <div class="col-md-10">
        <?php if(isset($err)) { echo $err; } ?>
        <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
            <li><a href="index.php?p=Payslipitems" style="color: rgb(7, 133, 164)">Payslip Items</a></li>
            <li><a href="index.php?p=allowances" style="color: rgb(7, 133, 164)">Allowances List</a></li>
            <li class="active">Edit Allowance</li>
        </ul>
        <div class="panel panel-default">
            <div class="panel-heading">
                <h3 class="panel-title"><b>Edit Allowance</b></h3>
            </div>
            <div class="panel-body" style="background: #fff">
                <form class="form-horizontal" action="" method="post">
                    <!-- First Row -->
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="employeeName">Employee Name</label>
                                <select class="form-control select" name="employeeName" id="employeeName">
                                    <?php
                                    // Establish connection and execute the query
                                    $selectQuery = "SELECT id, CONCAT(Fname, ' ', Lname) AS FullName FROM Employee_Registration";
                                    $result = mysqli_query($con, $selectQuery);
                                    // Check if there are rows returned
                                    if ($result && mysqli_num_rows($result) > 0) {
                                        // Loop through each row and populate the dropdown options
                                        while ($row = mysqli_fetch_assoc($result)) {
                                            $selected = ($row['id'] == $allowance['employee_id']) ? 'selected' : '';
                                            echo '<option value="' . $row['id'] . '" ' . $selected . '>' . $row['FullName'] . '</option>';
                                        }
                                    } else {
                                        echo '<option value="">No employees found</option>';
                                    }
                                    ?>
                                </select>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="category">Category</label>
                                <select class="form-control select" data-live-search="true" name="category" id="category">
                                    <option value="">Select Allowance</option>
                                    <option value="housing" <?php echo ($allowance['category'] == 'housing') ? 'selected' : ''; ?>>Housing Allowance</option>
                                    <option value="transport" <?php echo ($allowance['category'] == 'transport') ? 'selected' : ''; ?>>Transport Allowance</option>
                                    <option value="meal" <?php echo ($allowance['category'] == 'meal') ? 'selected' : ''; ?>>Meal Allowance</option>
                                    <option value="medical" <?php echo ($allowance['category'] == 'medical') ? 'selected' : ''; ?>>Medical Allowance</option>
                                    <option value="education" <?php echo ($allowance['category'] == 'education') ? 'selected' : ''; ?>>Education Allowance</option>
                                    <option value="responsibility" <?php echo ($allowance['category'] == 'responsibility') ? 'selected' : ''; ?>>Responsibility Allowance</option>
                                    <option value="travel" <?php echo ($allowance['category'] == 'travel') ? 'selected' : ''; ?>>Travel Allowance</option>
                                    <option value="hardship" <?php echo ($allowance['category'] == 'hardship') ? 'selected' : ''; ?>>Hardship Allowance</option>
                                    <option value="shift" <?php echo ($allowance['category'] == 'shift') ? 'selected' : ''; ?>>Shift Allowance</option>
                                    <option value="overtime" <?php echo ($allowance['category'] == 'overtime') ? 'selected' : ''; ?>>Overtime Allowance</option>
                                    <option value="acting" <?php echo ($allowance['category'] == 'acting') ? 'selected' : ''; ?>>Acting Allowance</option>
                                    <option value="uniform" <?php echo ($allowance['category'] == 'uniform') ? 'selected' : ''; ?>>Uniform Allowance</option>
                                </select>                
                            </div>
                        </div>
                    </div><br/>

                    <!-- Second Row -->
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="deductionStartDate">Date</label>
                                <input type="text" class="form-control datepicker datepicker-from" value="<?php echo htmlspecialchars($allowance['date']); ?>" name="date">
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="loanAmount">Amount</label>
                                <input type="number" class="form-control" name="amount" value="<?php echo htmlspecialchars($allowance['amount']); ?>" placeholder="Enter Amount">
                            </div>
                        </div>
                    </div>
                     
                </div>
                <div class="panel-footer">
                    <button type="submit" class="btn btn-primary pull-right" name="submit">Submit</button>
                </div>
            </form>
        </div>
    </div>
    <!-- END TIMELINE -->
</div>
