<?php
require_once '../db/connect.php';


if (!isset($_SESSION['role']) || $_SESSION['role'] != 1) { 
    echo "<script>
        Swal.fire({
            icon: 'error',
            title: 'Access Denied!',
            text: 'Only Admins can assign permissions.'
        });
    </script>";
    exit();
}

function assignPermission($role_id, $permission_id) {
    global $pdo;

    try {
        
        $stmt = $pdo->prepare("
            SELECT 1 
            FROM role_permissions 
            WHERE role_id = ? AND permission_id = ?
        ");
        $stmt->execute([$role_id, $permission_id]);

        if ($stmt->fetch()) {
            echo "
            <script>
                Swal.fire({
                    icon: 'warning',
                    title: 'Permission Already Assigned',
                    text: 'This permission is already assigned to the selected role.',
                    confirmButtonText: 'OK'
                });
            </script>";
            return false;
        }

        $stmt = $pdo->prepare("
            INSERT INTO role_permissions (role_id, permission_id) 
            VALUES (?, ?)
        ");
        $stmt->execute([$role_id, $permission_id]);

        echo "
        <script>
            Swal.fire({
                icon: 'success',
                title: 'Permission Assigned',
                text: 'Permission has been successfully assigned to the role.',
                confirmButtonText: 'OK'
            });
        </script>";
        return true;
    } catch (Exception $e) {
        echo "
        <script>
            Swal.fire({
                icon: 'error',
                title: 'Error Occurred',
                text: 'An error occurred while assigning the permission: " . $e->getMessage() . "',
                confirmButtonText: 'OK'
            });
        </script>";
        return false;
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $role_id = $_POST['role'];
    $permissions = $_POST['permissions'] ?? [];

    foreach ($permissions as $permission_id) {
        assignPermission($role_id, $permission_id);
    }
}
?>


<div class="col-md-9">  
    <div class="row">
        <div class="col-md-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>ADD PERMISSIONS</b></h3>
                </div>
                <div class="panel-body" style="background: #fff">
                    <form class="form-horizontal" method="post" action="" id="permissionForm">
                        <div class="form-group">
                            <label class="col-md-3 control-label">Role</label>
                            <div class="col-md-6 col-xs-12">  
                                <select class="form-control select" data-live-search="true" name="role" id="role" required>
                                     <?php
                                        // Fetch roles from the database
                                        $stmt = $pdo->query("SELECT * FROM roles");
                                        while ($row = $stmt->fetch()) {
                                            echo "<option value='" . htmlspecialchars($row['id']) . "'>" . htmlspecialchars($row['role_name']) . "</option>";
                                        }
                                        ?>
                                </select>
                            </div>
                        </div>
                        <div class="form-group">
                            <label class="col-md-3 control-label">Permissions:</label>
                            <div class="col-md-6 col-xs-12">                        
                                <?php
                                // Fetch permissions from the database
                                $stmt = $pdo->query("SELECT * FROM permissions");
                                while ($row = $stmt->fetch()) {
                                    echo "
                                        <label>
                                            <input type='checkbox' name='permissions[]' value='" . htmlspecialchars($row['id']) . "'> 
                                            " . htmlspecialchars($row['permission_name']) . "
                                        </label><br>
                                    ";
                                }
                                ?>
                            </div>
                        </div>
                </div>
                 <div class="panel-footer">                                    
                            <button class="btn btn-warning pull-right" type="submit" name="finish">
                                <span class="fa fa-arrow-right">Add</span> 
                            </button>
                        </div>
                    </form>
            </div>
        </div>
    </div>
</div>
