<?php
include '../db/db.php'; // Ensure the path is correct

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Fetch and sanitize input parameters
$startDate = mysqli_real_escape_string($con, $_GET['date1']);
$endDate = mysqli_real_escape_string($con, $_GET['date2']);
$supplierId = mysqli_real_escape_string($con, $_GET['supplier']);

// Prepare the SQL queries
$invoiceQuery = "
    SELECT 
        p.Name AS product_name, 
        pr.purchase_date, 
        pi.quantity, 
        pi.unit_price, 
        pi.total_price, 
        'Purchase Invoice' AS type,
        s.name AS supplier_name
    FROM purchase_invoice_items pi
    JOIN purchase_invoice pr ON pi.purchase_no = pr.purchase_id
    JOIN product p ON pi.product_id = p.ProductId
    JOIN supplier s ON pr.supplier_id = s.id
    WHERE pr.purchase_date BETWEEN ? AND ? AND pr.supplier_id = ?
    ORDER BY pr.purchase_date DESC
";

$purchaseQuery = "
    SELECT 
        p.Name AS product_name, 
        pr.purchase_date, 
        pr.due_date,
        pi.quantity, 
        pi.unit_price, 
        pi.total_price,
        'Cash Purchase' AS type,
        s.name AS supplier_name
    FROM purchase_items pi
    JOIN purchases pr ON pi.purchase_no = pr.purchase_id
    JOIN product p ON pi.product_id = p.ProductId
    JOIN supplier s ON pr.supplier_id = s.id
    WHERE pr.purchase_date BETWEEN ? AND ? AND pr.supplier_id = ?
    ORDER BY pr.purchase_date DESC
";

// Prepare and execute queries for invoices
$stmtInvoice = $con->prepare($invoiceQuery);
$stmtInvoice->bind_param('ssi', $startDate, $endDate, $supplierId);
$stmtInvoice->execute();
$resultInvoice = $stmtInvoice->get_result();

// Prepare and execute queries for purchases
$stmtPurchase = $con->prepare($purchaseQuery);
$stmtPurchase->bind_param('ssi', $startDate, $endDate, $supplierId);
$stmtPurchase->execute();
$resultPurchase = $stmtPurchase->get_result();

// Calculate total price and fetch all rows
$totalPrice = 0;
$data = [];
while ($row = $resultInvoice->fetch_assoc()) {
    $totalPrice += $row['total_price'];
    $data[] = $row;
}
while ($row = $resultPurchase->fetch_assoc()) {
    $totalPrice += $row['total_price'];
    $data[] = $row;
}

// Fetch supplier name
$supplierQuery = "
    SELECT s.name AS supplier_name
    FROM supplier s
    WHERE s.id = ?
    LIMIT 1
";
$supplierStmt = $con->prepare($supplierQuery);
$supplierStmt->bind_param('i', $supplierId);
$supplierStmt->execute();
$supplierResult = $supplierStmt->get_result();
$supplierRow = $supplierResult->fetch_assoc();
$supplierName = htmlspecialchars($supplierRow['supplier_name'] ?? 'Unknown');

// Close the statement and connection
$stmtInvoice->close();
$stmtPurchase->close();
$supplierStmt->close();
$con->close();
?>

<!-- HTML and Styles -->
<style>
    /* CSS to style the table */
    table {
        border-collapse: collapse;
        border: 1px solid black; /* Set border color and thickness */
        width: 100%; /* Set table width to 100% of its container */
    }

    th {
        border: 1px solid black; /* Set border for table cells */
        padding: 8px; /* Add padding for better readability */
        text-align: center; /* Center-align text within cells */
        height:20px;
        color:black;
    }
    td {
        border: 1px solid black; /* Set border for table cells */
        padding: 8px; /* Add padding for better readability */
        height:20px;
        color:black;
    }
</style>

<div class="col-md-9">
    <div class="row">
        <div class="col-md-12">
            <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=purchases" style="color: rgb(7, 133, 164)">Purchases Menu</a></li>
                <li class="active">Purchases Analysis by Item Report</li>
            </ul>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title"><b>Purchase Analysis by Product Report</b></h3>
                    <div class="pull-right">
                        <button class="btn btn-default" onclick="history.back()"> <span class="fa fa-arrow-left"></span> Go Back</button>
                        <button class="btn btn-default" onclick="printTable()">
                            <span class="fa fa-print"></span> Print Report
                        </button>
                        <button class="btn btn-default" onclick="exportToExcel()">
                            <span class="fa fa-download"></span> Export To Excel
                        </button>
                    </div>
                </div>
                <div class="panel-body" style="background: #fff">
                    <table id="myTable">
                        <tr>
                            <th colspan=7><b>COMPANY: <?php echo $_SESSION['Company']; ?></b></th>
                        </tr>
                        <tr>
                            <th colspan=7><b>BRANCH: <?php echo $_SESSION['Branch']; ?></b></th>
                        </tr>
                        <tr>
                            <th colspan=7><b><?php echo $supplierName; ?></b></th>
                        </tr>
                        <tr>
                            <th>Product Name</th>
                            <th>Supplier Name</th>
                            <th>Purchase Date</th>
                            <th>Purchase Type</th>
                            <th>Quantity</th>
                            <th>Unit Price</th>
                            <th>Total Amount</th>
                        </tr>
                        <?php foreach ($data as $row) { ?>
                            <tr>
                                <td style="text-align:left"><?php echo htmlspecialchars($row['product_name']); ?></td>
                                <td style="text-align:left"><?php echo htmlspecialchars($row['supplier_name']); ?></td>
                                <td><?php echo htmlspecialchars($row['purchase_date']); ?></td>
                                <td><?php echo htmlspecialchars($row['type']); ?></td>
                                <td><?php echo htmlspecialchars($row['quantity']); ?></td>
                                <td><?php echo number_format($row['unit_price'], 2); ?></td>
                                <td style="text-align:right"><?php echo number_format($row['total_price'], 2); ?></td>
                            </tr>
                        <?php } ?>
                        <tr class="total-row">
                            <td colspan="6" style="text-align:left">Total Amount</td>
                            <td style="text-align:right"><b><?php echo number_format($totalPrice, 2); ?></b></td>
                        </tr>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
function exportToExcel() {
    // Get the HTML table element
    var table = document.querySelector('table');
    
    // Set the border color to black for all table cells
    var cells = table.querySelectorAll('th, td');
    cells.forEach(function(cell) {
        cell.style.border = "1px solid black";
    });

    // Convert the HTML table to a worksheet
    var wb = XLSX.utils.table_to_book(table, {sheet: "Sheet1", raw: true});

    // Style the Excel sheet with borders
    wb.Sheets["Sheet1"]["!cols"] = [{wch: 15}, {wch: 30}, {wch: 15}]; // Adjust column widths as needed
    wb.Sheets["Sheet1"]["!rows"] = [{hpx: 20}]; // Set row height

    // Generate a binary string from the XLSX workbook
    var wbout = XLSX.write(wb, { bookType: 'xlsx', type: 'binary' });

    // Create a Blob object representing the data as an Excel file
    var blob = new Blob([s2ab(wbout)], { type: 'application/octet-stream' });

    // Create a temporary anchor element and trigger a download
    var link = document.createElement('a');
    link.href = window.URL.createObjectURL(blob);
    link.download = 'supplier_analysis_byProduct.xlsx'; // Change 'filename' to your desired filename
    link.click();
}

// Utility function to convert a string to an ArrayBuffer
function s2ab(s) {
    var buf = new ArrayBuffer(s.length);
    var view = new Uint8Array(buf);
    for (var i = 0; i < s.length; i++) {
        view[i] = s.charCodeAt(i) & 0xFF;
    }
    return buf;
}

function exportToPDF() {
    // Get the HTML table element
    var table = document.querySelector('table');

    // Initialize jsPDF
    var doc = new jsPDF();

    // Add header
    doc.setFontSize(16);
    doc.text("CUSTOMER TRANSACTIONS", 10, 10);

    // Add table using autotable plugin
    doc.autoTable({
        html: table,
        startY: 20,
        theme: 'plain', // Use 'grid' for borders
        styles: { fillColor: [255, 255, 255], textColor: [0, 0, 0], lineWidth: 0.1 },
        headStyles: { fillColor: [200, 200, 200], textColor: [0, 0, 0], lineWidth: 0.1 },
        bodyStyles: { textColor: [0, 0, 0], lineWidth: 0.1 }
    });

    // Save the PDF
    doc.save('table.pdf');
}

function printTable() {
    // Apply border style to table cells
    var cells = document.querySelectorAll('td, th');
    cells.forEach(function(cell) {
        cell.style.border = '1px solid black';
    });

    // Print only the table
    var printWindow = window.open('', '_blank');
    printWindow.document.open();
    printWindow.document.write('<html><head><title>Print Table</title></head><body>');
    printWindow.document.write('<style>table { border-collapse: collapse; width: 100%; } th, td { border: 1px solid black; padding: 8px; }</style>');
    printWindow.document.write(document.getElementById('myTable').outerHTML);
    printWindow.document.write('</body></html>');
    printWindow.document.close();
    printWindow.print();

    // Remove border style after printing
    cells.forEach(function(cell) {
        cell.style.border = '';
    });
}
</script>
