<?php
require_once '../db/connection.php';

try {
    $pdo = new PDO($dsn, $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Check if 'id' is set in the GET request
    if (isset($_GET['id']) && !empty($_GET['id'])) {
        // Decrypt the provided ID
        $id =  mysqli_real_escape_string($con,$_GET['id']);

        if (!$id) {
            die("Invalid or corrupted ID parameter!");
        }

        // Fetch the existing data from the database
        $stmt = $pdo->prepare("SELECT * FROM ngm_customer WHERE id = ?");
        $stmt->execute([$id]);
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$row) {
            // Handle if no record is found for the provided ID
            echo "Record not found for ID: $id";
            exit;
        }

        // Extract fetched data to populate the form fields
        $name = $row['name'];
        $phone = $row['phone1'];
        $location = $row['location'];
        $email = $row['email'];
        $tin = $row['tin'];
        $vrn = $row['vrn'];
    } else {
        die("ID parameter is missing in the URL!");
    }

    // Update record in the database on form submission
    if (isset($_POST['submit'])) {
        // Retrieve and validate form data
        $name = strtoupper($_POST['name']);
        $location = $_POST['location'];
        $email = $_POST['email'];
        $phone = $_POST['phone'];
        $tin = $_POST['tin'];
        $vrn = $_POST['vrn'];

        // Validate phone number length
        if (strlen($phone) !== 12) {
            $err = "<p class='alert alert-danger'>Invalid phone number! 
                    Please ensure the phone number is 12 digits long.</p>";
        } else {
            // Update the record in the database
            $stmt = $pdo->prepare("UPDATE ngm_customer 
                SET name = ?, location = ?, phone1 = ?, email = ?, tin = ?, vrn = ? 
                WHERE id = ?");
            $stmt->execute([$name, $location, $phone, $email, $tin, $vrn, $id]);

            if ($stmt->rowCount() > 0) {
                // Successful update
                echo "<script>
                        alert('Customer updated successfully!');
                        window.location = 'index.php?p=customers';
                      </script>";
            } else {
                // Handle update failure
                echo "<p class='alert alert-danger'>Failed to update the record!</p>";
            }
        }
    }
} catch (PDOException $e) {
    // Handle database errors
    echo "Database error: " . $e->getMessage();
}
?>

                            <div class="col-md-9">
                                <ul class="breadcrumb" style="height: 40px; padding-top: 10px;">
                <li><a href="index.php?p=sales" style="color: rgb(7, 133, 164)">Sales Menu</a></li>
                <li><a href="index.php?p=customers" style="color: rgb(7, 133, 164)">Customers List</a></li>
                <li class="active">Customers Edit</li>
            </ul>

                            <!-- START TIMELINE -->
                            <div class="row">
                            <div class="col-md-12">

                             <div class="panel panel-default">
                                <div class="panel-heading">
                                    <h3 class="panel-title"><b>EDIT CUSTOMER</b></h3>
                                    <div class="pull-right">
                                        <a href="index.php?p=customers"><button class="btn btn-warning"> <span class="fa fa-plus-circle"></span> View Customers</button></a>
                                    </div>
                                </div>
                                <div class="panel-body" style="background: #fff">
                                    <?php if(isset($err)){ echo $err;}?>
                                    <form action = "" method="post">
                                    <div class="row"> 
                                     <div class="col-md-4">  
                                      <div class="form-group">
                                        <div class="col-md-12 col-xs-12">                      
                                            <div class="input-group">
                                                <span class="input-group-addon">Name</span>
                                                <input type="text" name = "name" class="form-control" placeholder="Enter Name or Business" value = "<?php echo $name;?>"/>
                                            </div>                                            
                                        </div>
                                       </div>                     
                                     </div>
                                      <div class="col-md-4">  
                                      <div class="form-group">
                                        <div class="col-md-12 col-xs-12">                                     
                                            <div class="input-group">
                                                <span class="input-group-addon">Phone#</span>
                                                <input type="text" name = "phone" class="form-control" placeholder="Enter Mobile Number" value = "<?php echo $phone;?>"/>
                                            </div>                                            
                                        </div>
                                      </div>                     
                                     </div>
                                   </div>

                                    <br/><br/>
                                    <div class="row"> 
                                     <div class="col-md-4">  
                                      <div class="form-group">
                                        <div class="col-md-12 col-xs-12">                                            
                                            <div class="input-group">
                                                <span class="input-group-addon">Address</span>
                                                <input type="text" name = "location" class="form-control" placeholder="Enter Location" value = "<?php echo $location;?>"/>
                                            </div>              
                                        </div>
                                     </div>                    
                                     </div>
                                      <div class="col-md-4">  
                                      <div class="form-group">
                                        <div class="col-md-12 col-xs-12">                                            
                                            <div class="input-group">
                                                <span class="input-group-addon">Email</span>
                                                <input type="text" name = "email" class="form-control" placeholder="Enter Email" value = "<?php echo $email;?>"/>
                                            </div>              
                                        </div>
                                     </div>                    
                                     </div>

                                    </div>
                                   <br><br/>
                                   <div class="row"> 
                                     <div class="col-md-4">  
                                      <div class="form-group">
                                        <div class="col-md-12 col-xs-12">                                            
                                            <div class="input-group">
                                                <span class="input-group-addon">TIN</span>
                                                <input type="text" name = "tin" class="form-control" placeholder="" value = "<?php echo $tin;?>"/>
                                            </div>              
                                        </div>
                                     </div>                    
                                     </div>
                                      <div class="col-md-4">  
                                      <div class="form-group">
                                        <div class="col-md-12 col-xs-12">                                            
                                            <div class="input-group">
                                                <span class="input-group-addon">VRN</span>
                                                <input type="text" name = "vrn" class="form-control" placeholder="" value = "<?php echo $vrn;?>"/>
                                            </div>              
                                        </div>
                                     </div>                    
                                     </div>

                                    </div><br/><br/>
                                </div>
                                <div class="panel-footer">               
                                    <button class="btn btn-info pull-right" type = "submit" name = "submit"><span class="fa fa-edit"></span> Update</button>
                                </div>
                            </form>
                            </div>
                          </div>
                        </div>
                            <!-- END TIMELINE -->                            
                            
                        </div>